@@ -3,7 +3,7 @@
 /*
     bqaudioio
 
-    Copyright 2007-2016 Particular Programs Ltd.
+    Copyright 2007-2021 Particular Programs Ltd.
 
     Permission is hereby granted, free of charge, to any person
     obtaining a copy of this software and associated documentation
@@ -135,7 +135,7 @@ private:
     // These three should be called with m_mutex held already
     void deconstructResampler();
     void reconstructResampler();
-    void setupBuffersFor(int reqsize);
+    void checkBuffersFor(int reqsize);
 
     ResamplerWrapper(const ResamplerWrapper &)=delete;
     ResamplerWrapper &operator=(const ResamplerWrapper &)=delete;
