@@ -32,13 +32,13 @@
     Software without prior written authorization.
 */
 
-#include "AudioWriteStreamFactory.h"
-#include "AudioWriteStream.h"
+#include "../bqaudiostream/AudioWriteStreamFactory.h"
+#include "../bqaudiostream/AudioWriteStream.h"
 
 #include "bqthingfactory/ThingFactory.h"
-#include "Exceptions.h"
+#include "../bqaudiostream/Exceptions.h"
 
-#include "AudioReadStreamFactory.h"
+#include "../bqaudiostream/AudioReadStreamFactory.h"
 
 namespace breakfastquay {
 
@@ -60,7 +60,7 @@ AudioWriteStreamFactory::createWriteStream(std::string audioFileName,
 
     AudioWriteStreamFactoryImpl *f = AudioWriteStreamFactoryImpl::getInstance();
 
-    if (extension == "") {
+    if (extension == "" || extension.size() > 4) {
         // We explicitly support extension-less filenames and write
         // them in RIFF/WAVE format. (This is in order to support
         // programmatically generated temporary files created with
@@ -70,7 +70,7 @@ AudioWriteStreamFactory::createWriteStream(std::string audioFileName,
     
     try {
         AudioWriteStream *stream = f->createFor(extension, target);
-        if (!stream) throw UnknownFileType(audioFileName);
+        if (!stream) throw FailedToWriteFile(audioFileName);
         return stream;
     } catch (const UnknownTagException &) {
         throw UnknownFileType(audioFileName);
@@ -141,8 +141,15 @@ AudioWriteStreamFactory::isExtensionSupportedFor(std::string fileName)
 // #ifdef'd out if the implementation is not selected, so there is no
 // overhead.
 
+// WavFileWriteStream uses libsndfile, which is mostly trustworthy
 #include "WavFileWriteStream.cpp"
+
+// SimpleWavFileWriteStream writes only 24-bit WAV files. The
+// dedicated WavFileReadStream using libsndfile is generally much
+// better and goes first
 #include "SimpleWavFileWriteStream.cpp"
+
 #include "CoreAudioWriteStream.cpp"
+
 #include "OpusWriteStream.cpp"
 
