@@ -510,7 +510,7 @@ private:
             DQ_DEBUG << "load: calling allocate(" << node << ")" << endl;
             try {
                 allocate(state, node);
-            } catch (const UnknownTypeException &e) {
+            } catch (const UnknownTypeException &) {
                 if (state.loadFlags & LoadState::IgnoreUnknownTypes) {
                     DQ_DEBUG << "load: IgnoreUnknownTypes is set, removing object of unknown type and continuing" << endl;
                     delete state.map.value(node);
