@@ -51,6 +51,7 @@
 #include "../version.h"
 
 using namespace std;
+using namespace sv;
 
 PreferencesDialog::PreferencesDialog(QWidget *parent) :
     QDialog(parent),
@@ -87,8 +88,8 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) :
                               ("Window Type", &min, &max, &deflt));
     m_windowTypeSelector = new WindowTypeSelector(m_windowType);
 
-    connect(m_windowTypeSelector, SIGNAL(windowTypeChanged(WindowType)),
-            this, SLOT(windowTypeChanged(WindowType)));
+    connect(m_windowTypeSelector, &WindowTypeSelector::windowTypeChanged,
+            this, &PreferencesDialog::windowTypeChanged);
 
     QCheckBox *vampProcessSeparation = new QCheckBox;
     m_runPluginsInProcess = prefs->getRunPluginsInProcess();
@@ -99,12 +100,12 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) :
     
     QComboBox *smoothing = new QComboBox;
     
-    int sm = prefs->getPropertyRangeAndValue("Spectrogram Y Smoothing", &min, &max,
+    int sm = prefs->getPropertyRangeAndValue("Spectrogram Smoothing", &min, &max,
                                              &deflt);
     m_spectrogramSmoothing = sm;
 
     for (i = min; i <= max; ++i) {
-        smoothing->addItem(prefs->getPropertyValueLabel("Spectrogram Y Smoothing", i));
+        smoothing->addItem(prefs->getPropertyValueLabel("Spectrogram Smoothing", i));
     }
 
     smoothing->setCurrentIndex(sm);
@@ -112,21 +113,6 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) :
     connect(smoothing, SIGNAL(currentIndexChanged(int)),
             this, SLOT(spectrogramSmoothingChanged(int)));
 
-    QComboBox *xsmoothing = new QComboBox;
-    
-    int xsm = prefs->getPropertyRangeAndValue("Spectrogram X Smoothing", &min, &max,
-                                             &deflt);
-    m_spectrogramXSmoothing = xsm;
-
-    for (i = min; i <= max; ++i) {
-        xsmoothing->addItem(prefs->getPropertyValueLabel("Spectrogram X Smoothing", i));
-    }
-
-    xsmoothing->setCurrentIndex(xsm);
-
-    connect(xsmoothing, SIGNAL(currentIndexChanged(int)),
-            this, SLOT(spectrogramXSmoothingChanged(int)));
-
     QComboBox *propertyLayout = new QComboBox;
     int pl = prefs->getPropertyRangeAndValue("Property Box Layout", &min, &max,
                                          &deflt);
@@ -155,7 +141,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) :
         QString qcolorName =
             settings.value("overview-colour", m_overviewColour.name())
             .toString();
-        m_overviewColour.setNamedColor(qcolorName);
+        m_overviewColour = QColor(qcolorName);
         m_overviewColourIsSet = true;
         SVCERR << "loaded colour " << m_overviewColour.name() << " from settings" << endl;
     }
@@ -338,7 +324,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) :
     if (userLocale == "") {
         locale->setCurrentIndex(0);
     }
-    foreach (QString f, localeFiles) {
+    for (QString f : localeFiles) {
         QString f0 = f;
         f.replace("sonic-visualiser_", "").replace(".qm", "");
         if (f == f0) { // our expectations about filename format were not met
@@ -483,15 +469,10 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) :
     subgrid->addWidget(octaveSystem, row++, 1, 1, 2);
 
     subgrid->addWidget(new QLabel(prefs->getPropertyLabel
-                                  ("Spectrogram Y Smoothing")),
+                                  ("Spectrogram Smoothing")),
                        row, 0);
     subgrid->addWidget(smoothing, row++, 1, 1, 2);
 
-    subgrid->addWidget(new QLabel(prefs->getPropertyLabel
-                                  ("Spectrogram X Smoothing")),
-                       row, 0);
-    subgrid->addWidget(xsmoothing, row++, 1, 1, 2);
-
     subgrid->addWidget(new QLabel(tr("%1:").arg(prefs->getPropertyLabel
                                                 ("Window Type"))),
                        row, 0);
@@ -540,11 +521,11 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) :
     QStringList templates = ResourceFinder().getResourceFiles("templates", "svt");
 
     set<QString> byName;
-    foreach (QString t, templates) {
+    for (QString t : templates) {
         byName.insert(QFileInfo(t).baseName());
     }
 
-    foreach (QString t, byName) {
+    for (QString t : byName) {
         if (t.toLower() == "default") continue;
         m_templates.push_back(t);
         lw->addItem(t);
@@ -731,13 +712,6 @@ PreferencesDialog::spectrogramSmoothingChanged(int smoothing)
     m_applyButton->setEnabled(true);
 }
 
-void
-PreferencesDialog::spectrogramXSmoothingChanged(int smoothing)
-{
-    m_spectrogramXSmoothing = smoothing;
-    m_applyButton->setEnabled(true);
-}
-
 void
 PreferencesDialog::spectrogramGColourChanged(int colour)
 {
@@ -985,8 +959,6 @@ PreferencesDialog::applyClicked()
     prefs->setWindowType(WindowType(m_windowType));
     prefs->setSpectrogramSmoothing(Preferences::SpectrogramSmoothing
                                    (m_spectrogramSmoothing));
-    prefs->setSpectrogramXSmoothing(Preferences::SpectrogramXSmoothing
-                                   (m_spectrogramXSmoothing));
     prefs->setPropertyBoxLayout(Preferences::PropertyBoxLayout
                                 (m_propertyLayout));
     prefs->setTuningFrequency(m_tuningFrequency);
