@@ -1,14 +1,11 @@
 #!/bin/sh
 
+set -eu
+
 LANGUAGES="ru en_GB en_US cs_CZ"
 
-LUPDATE="lupdate"
-LRELEASE="lrelease"
-
-if lupdate-qt5 -version >/dev/null 2>&1; then
-    LUPDATE="lupdate-qt5"
-    LRELEASE="lrelease-qt5"
-fi
+LUPDATE="/usr/lib/qt6/bin/lupdate"
+LRELEASE="/usr/lib/qt6/bin/lrelease"
 
 for LANG in $LANGUAGES; do
     $LUPDATE \
