@@ -29,6 +29,8 @@
 #include <QSettings>
 #include <QTimer>
 
+namespace sv {
+
 using std::make_shared;
 
 QString
@@ -292,12 +294,19 @@ bool
 Align::canAlign() 
 {
     AlignmentType type = getAlignmentPreference();
+    bool subsequence = getUseSubsequenceAlignment();
 
     if (type == ExternalProgramAlignment) {
+        SVDEBUG << "Align::canAlign: type is ExternalProgramAlignment, "
+                << "querying ExternalProgramAligner" << endl;
         return ExternalProgramAligner::isAvailable
             (getPreferredAlignmentProgram());
     } else {
-        return MATCHAligner::isAvailable();
+        SVDEBUG << "Align::canAlign: type is not ExternalProgramAlignment, "
+                << "querying MATCHAligner" << endl;
+        return MATCHAligner::isAvailable
+            (subsequence,
+             type == MATCHAlignmentWithPitchCompare);
     }
 }
 
@@ -334,3 +343,5 @@ Align::removeAligner(QObject *obj)
     }
 }
 
+} // end namespace sv
+
