@@ -20,6 +20,8 @@
 
 //#define DEBUG_DTW 1
 
+namespace sv {
+
 template <typename Value>
 class DTW
 {
@@ -276,4 +278,6 @@ inline std::ostream &operator<<(std::ostream &s, const RiseFallDTW::Value v) {
             << v.distance);
 }
 
+} // end namespace sv
+
 #endif
