@@ -20,6 +20,8 @@
 #include <QProcess>
 #include <QString>
 
+namespace sv {
+
 class AlignmentModel;
 class Document;
 
@@ -53,4 +55,6 @@ private:
     QProcess *m_process;
 };
 
+} // end namespace sv
+
 #endif
