@@ -40,6 +40,8 @@ namespace breakfastquay {
     class ResamplerWrapper;
 }
 
+namespace sv {
+
 class Model;
 class ViewManagerBase;
 class AudioGenerator;
@@ -307,6 +309,17 @@ public:
      */
     void clearSoloModelSet();
 
+    /**
+     * For historical reasons AudioCallbackPlaySource by default
+     * always emits at least 2 channels, and insists that the output
+     * device (or whatever abstraction is provided for it) supports at
+     * least 2. Call setEnforceStereo(false) to avoid this and reduce
+     * the minimum number of channels to 1.
+     */
+    void setEnforceStereo(bool enforce) {
+        m_enforceStereo = enforce;
+    }
+
     virtual std::string getClientName() const override {
         return m_clientName;
     }
@@ -371,6 +384,10 @@ protected:
     bool                              m_exiting;
     sv_frame_t                        m_lastModelEndFrame;
     int                               m_ringBufferSize;
+    float                            *m_tmpMixbuf;
+    sv_frame_t                        m_tmpMixbufSize;
+    float                           **m_chunkBufferPtrs;
+    int                               m_chunkBufferPtrCount;
     float                             m_outputLeft;
     float                             m_outputRight;
     bool                              m_levelsSet;
@@ -378,6 +395,7 @@ protected:
     sv_frame_t                        m_playStartFrame;
     bool                              m_playStartFramePassed;
     RealTime                          m_playStartedAt;
+    bool                              m_enforceStereo;
 
     RingBuffer<float> *getWriteRingBuffer(int c) {
         if (m_writeBuffers && c < (int)m_writeBuffers->size()) {
@@ -437,5 +455,7 @@ protected:
     void checkWrappers();
 };
 
+} // end namespace sv
+
 #endif
 
