@@ -18,6 +18,8 @@
 
 #include "base/RangeMapper.h"
 
+namespace sv {
+
 class PlaySpeedRangeMapper : public RangeMapper
 {
 public:
@@ -46,4 +48,6 @@ protected:
 };
 
 
+} // end namespace sv
+
 #endif
