@@ -488,6 +488,28 @@ Document::setMainModel(ModelId modelId)
     }
 }
 
+void
+Document::switchMainModel(ModelId modelId)
+{
+    SVDEBUG << "Document::switchMainModel: switching main model "
+            << m_mainModel << " to model " << modelId << endl;
+
+    if (m_mainModel == modelId) {
+        return;
+    }
+    
+    m_models.erase(modelId);
+    m_mainModel = modelId;
+    
+    if (auto model = ModelById::get(modelId)) {
+        emit activity(tr("Switch main model to %1").arg(model->objectName()));
+    } else {
+        emit activity(tr("Switch main model to nothing"));
+    }
+
+    emit mainModelChanged(m_mainModel);
+}
+
 void
 Document::refreshModel(ModelId modelId)
 {
@@ -861,6 +883,7 @@ Document::releaseModel(ModelId modelId)
 #pragma clang diagnostic ignored "-Wpotentially-evaluated-expression"
 #endif
 
+#ifdef DEBUG_DOCUMENT
     if (auto model = ModelById::get(modelId)) {
         SVCERR << "Document::releaseModel(" << modelId << "), name "
                << model->objectName() << ", type "
@@ -868,6 +891,7 @@ Document::releaseModel(ModelId modelId)
     } else {
         SVCERR << "Document::releaseModel(" << modelId << ")" << endl;
     }
+#endif
     
     if (modelId.isNone()) {
         return;
