@@ -40,6 +40,21 @@
 
 #include <map>
 
+class QMenu;
+class QLabel;
+class QCheckBox;
+class QTreeView;
+class QPushButton;
+class QSignalMapper;
+class QShortcut;
+
+namespace breakfastquay {
+    class SystemPlaybackTarget;
+    class SystemAudioIO;
+}
+
+namespace sv {
+
 class Document;
 class PaneStack;
 class Pane;
@@ -53,31 +68,18 @@ class AudioCallbackPlaySource;
 class TimeStretchWrapper;
 class AudioCallbackRecordTarget;
 class CommandHistory;
-class QMenu;
 class AudioDial;
 class LevelPanWidget;
 class LevelPanToolButton;
-class QLabel;
-class QCheckBox;
-class PreferencesDialog;
-class QTreeView;
-class QPushButton;
 class OSCMessage;
 class OSCScript;
 class MIDIInput;
 class KeyReference;
 class Labeller;
 class ModelDataTableDialog;
-class QSignalMapper;
-class QShortcut;
 class AlignmentModel;
 class LayerGeometryProvider;
 
-namespace breakfastquay {
-    class SystemPlaybackTarget;
-    class SystemAudioIO;
-}
-
 /**
  * The base class for the SV main window.  This includes everything to
  * do with general document and pane stack management, but nothing
@@ -524,7 +526,7 @@ protected:
     class AddPaneCommand : public Command
     {
     public:
-        AddPaneCommand(MainWindowBase *mw);
+        AddPaneCommand(MainWindowBase *mw, int atIndex = -1);
         virtual ~AddPaneCommand();
         
         void execute() override;
@@ -535,6 +537,7 @@ protected:
 
     protected:
         MainWindowBase *m_mw;
+        int m_atIndex;
         Pane *m_pane; // Main window owns this, but I determine its lifespan
         Pane *m_prevCurrentPane; // I don't own this
         bool m_added;
@@ -599,4 +602,6 @@ protected:
 };
 
 
+} // end namespace sv
+
 #endif
