@@ -26,6 +26,8 @@
 
 #include <stdexcept>
 
+namespace sv {
+
 class OSCScript : public QThread
 {
     Q_OBJECT
@@ -127,5 +129,7 @@ private:
     bool m_abandoning;
 };
 
+} // end namespace sv
+
 #endif
 
