@@ -30,6 +30,8 @@
 
 #include <typeinfo>
 
+namespace sv {
+
 static QWidget *parentWidget = nullptr;
 
 void
@@ -240,3 +242,5 @@ TransformUserConfigurator::configure(ModelTransformer::Input &input,
     return ok;
 }
 
+} // end namespace sv
+
