@@ -15,6 +15,8 @@
 
 #include "Clipboard.h"
 
+namespace sv {
+
 Clipboard::Clipboard() { }
 Clipboard::~Clipboard() { }
 
@@ -68,3 +70,5 @@ Clipboard::referenceFramesDiffer() const
     return false;
 }
 
+} // end namespace sv
+
