@@ -20,6 +20,8 @@
 
 #include "Event.h"
 
+namespace sv {
+
 class Clipboard
 {
 public:
@@ -39,4 +41,6 @@ protected:
     EventVector m_points;
 };
 
+} // end namespace sv
+
 #endif
