@@ -22,6 +22,8 @@
 #include <QDir>
 #include <QFileInfo>
 
+namespace sv {
+
 QStringList
 HelperExecPath::getTags()
 {
@@ -112,6 +114,39 @@ HelperExecPath::getHelperDirPaths()
     return dirs;
 }
 
+QStringList
+HelperExecPath::getBundledPluginPaths()
+{
+    // Plugins are expected to exist in one of the following, in order
+    // from most strongly preferred to least:
+    //
+    // 1. (on Mac only) in <mydir>/../Resources
+    //
+    // 2. (on non-Windows non-Mac platforms only) in
+    // <mydir>/../lib/application-name/plugins/
+    //
+    // 3. (on non-Mac platforms only) in <mydir>/plugins/
+
+    QStringList dirs;
+    QString appName = QCoreApplication::applicationName();
+    QString myDir = QCoreApplication::applicationDirPath();
+    QString binaryName = QFileInfo(QCoreApplication::arguments().at(0))
+        .fileName();
+        
+#ifdef Q_OS_MAC
+    dirs.push_back(myDir + "/../Resources");
+#else
+#ifndef Q_OS_WIN32
+    if (binaryName != "") {
+        dirs.push_back(myDir + "/../lib/" + binaryName + "/plugins");
+    }
+    dirs.push_back(myDir + "/../lib/" + appName + "/plugins");
+#endif
+    dirs.push_back(myDir + "/plugins");
+#endif
+    return dirs;
+}
+
 QStringList
 HelperExecPath::getHelperCandidatePaths(QString basename)
 {
@@ -151,3 +186,4 @@ HelperExecPath::search(QString basename, QStringList &candidates)
     return executables;
 }
 
+}
