@@ -17,6 +17,8 @@
 
 #include "NoteData.h"
 
+namespace sv {
+
 class NoteExportable
 {
 public:
@@ -41,4 +43,6 @@ public:
                                             sv_frame_t duration) const = 0;
 };
 
+} // end namespace sv
+
 #endif
