@@ -24,19 +24,23 @@
 #include <QMutex>
 #include <QSettings>
 
+#include <mutex>
+
+namespace sv {
+
 Preferences *
 Preferences::m_instance = nullptr;
 
 Preferences *
 Preferences::getInstance()
 {
-    if (!m_instance) m_instance = new Preferences();
+    static std::once_flag f;
+    std::call_once(f, [&]() { m_instance = new Preferences(); });
     return m_instance;
 }
 
 Preferences::Preferences() :
     m_spectrogramSmoothing(SpectrogramInterpolated),
-    m_spectrogramXSmoothing(SpectrogramXInterpolated),
     m_tuningFrequency(440),
     m_propertyBoxLayout(VerticallyStacked),
     m_windowType(HanningWindow),
@@ -59,9 +63,7 @@ Preferences::Preferences() :
     QSettings settings;
     settings.beginGroup("Preferences");
     m_spectrogramSmoothing = SpectrogramSmoothing
-        (settings.value("spectrogram-y-smoothing", int(m_spectrogramSmoothing)).toInt());
-    m_spectrogramXSmoothing = SpectrogramXSmoothing
-        (settings.value("spectrogram-x-smoothing", int(m_spectrogramXSmoothing)).toInt());
+        (settings.value("spectrogram-smoothing", int(m_spectrogramSmoothing)).toInt());
     m_tuningFrequency = settings.value("tuning-frequency", 440.).toDouble();
     m_propertyBoxLayout = PropertyBoxLayout
         (settings.value("property-box-layout", int(VerticallyStacked)).toInt());
@@ -97,8 +99,7 @@ Preferences::PropertyList
 Preferences::getProperties() const
 {
     PropertyList props;
-    props.push_back("Spectrogram Y Smoothing");
-    props.push_back("Spectrogram X Smoothing");
+    props.push_back("Spectrogram Smoothing");
     props.push_back("Tuning Frequency");
     props.push_back("Property Box Layout");
     props.push_back("Window Type");
@@ -123,11 +124,8 @@ Preferences::getProperties() const
 QString
 Preferences::getPropertyLabel(const PropertyName &name) const
 {
-    if (name == "Spectrogram Y Smoothing") {
-        return tr("Spectrogram y-axis interpolation:");
-    }
-    if (name == "Spectrogram X Smoothing") {
-        return tr("Spectrogram x-axis interpolation:");
+    if (name == "Spectrogram Smoothing") {
+        return tr("Default spectrogram interpolation:");
     }
     if (name == "Tuning Frequency") {
         return tr("Frequency of concert A");
@@ -189,10 +187,7 @@ Preferences::getPropertyLabel(const PropertyName &name) const
 Preferences::PropertyType
 Preferences::getPropertyType(const PropertyName &name) const
 {
-    if (name == "Spectrogram Y Smoothing") {
-        return ValueProperty;
-    }
-    if (name == "Spectrogram X Smoothing") {
+    if (name == "Spectrogram Smoothing") {
         return ValueProperty;
     }
     if (name == "Tuning Frequency") {
@@ -257,18 +252,12 @@ int
 Preferences::getPropertyRangeAndValue(const PropertyName &name,
                                       int *min, int *max, int *deflt) const
 {
-    if (name == "Spectrogram Y Smoothing") {
+    if (name == "Spectrogram Smoothing") {
         if (min) *min = 0;
         if (max) *max = 1;
         if (deflt) *deflt = int(SpectrogramInterpolated);
         return int(m_spectrogramSmoothing);
     }
-    if (name == "Spectrogram X Smoothing") {
-        if (min) *min = 0;
-        if (max) *max = 1;
-        if (deflt) *deflt = int(SpectrogramXInterpolated);
-        return int(m_spectrogramXSmoothing);
-    }
 
     //!!! freq mapping
 
@@ -367,18 +356,12 @@ Preferences::getPropertyValueLabel(const PropertyName &name,
         case 2: return tr("Highest quality");
         }
     }
-    if (name == "Spectrogram Y Smoothing") {
+    if (name == "Spectrogram Smoothing") {
         switch (value) {
         case NoSpectrogramSmoothing: return tr("None");
         case SpectrogramInterpolated: return tr("Linear interpolation");
         }
     }
-    if (name == "Spectrogram X Smoothing") {
-        switch (value) {
-        case NoSpectrogramXSmoothing: return tr("None");
-        case SpectrogramXInterpolated: return tr("Linear interpolation");
-        }
-    }
     if (name == "Background Mode") {
         switch (value) {
         case BackgroundFromTheme: return tr("Follow desktop theme");
@@ -424,10 +407,8 @@ Preferences::getPropertyContainerIconName() const
 void
 Preferences::setProperty(const PropertyName &name, int value) 
 {
-    if (name == "Spectrogram Y Smoothing") {
+    if (name == "Spectrogram Smoothing") {
         setSpectrogramSmoothing(SpectrogramSmoothing(value));
-    } else if (name == "Spectrogram X Smoothing") {
-        setSpectrogramXSmoothing(SpectrogramXSmoothing(value));
     } else if (name == "Tuning Frequency") {
         //!!!
     } else if (name == "Property Box Layout") {
@@ -465,26 +446,9 @@ Preferences::setSpectrogramSmoothing(SpectrogramSmoothing smoothing)
 
         QSettings settings;
         settings.beginGroup("Preferences");
-        settings.setValue("spectrogram-y-smoothing", int(smoothing));
+        settings.setValue("spectrogram-smoothing", int(smoothing));
         settings.endGroup();
-        emit propertyChanged("Spectrogram Y Smoothing");
-    }
-}
-
-void
-Preferences::setSpectrogramXSmoothing(SpectrogramXSmoothing smoothing)
-{
-    if (m_spectrogramXSmoothing != smoothing) {
-
-        // "smoothing" is one of those words that looks increasingly
-        // ridiculous the more you see it.  Smoothing smoothing smoothing.
-        m_spectrogramXSmoothing = smoothing;
-
-        QSettings settings;
-        settings.beginGroup("Preferences");
-        settings.setValue("spectrogram-x-smoothing", int(smoothing));
-        settings.endGroup();
-        emit propertyChanged("Spectrogram X Smoothing");
+        emit propertyChanged("Spectrogram Smoothing");
     }
 }
 
@@ -773,3 +737,5 @@ Preferences::setShowSplash(bool show)
     }
 }
         
+} // end namespace sv
+
