@@ -15,6 +15,8 @@
 
 #include "ProgressReporter.h"
 
+namespace sv {
+
 ProgressReporter::ProgressReporter(QObject *parent) :
         QObject(parent)
 {
@@ -24,3 +26,5 @@ ProgressReporter::~ProgressReporter()
 {
 }
 
+} // end namespace sv
+
