@@ -17,6 +17,8 @@
 
 #include <QString>
 
+namespace sv {
+
 /**
  * Report the intended target location for recorded audio files.
  */
@@ -66,4 +68,6 @@ public:
     static QString getConvertedAudioDirectory();
 };
 
+} // end namespace sv
+
 #endif
