@@ -36,6 +36,8 @@
 #include <iostream>
 #endif
 
+namespace sv {
+
 /**
  * RingBuffer implements a lock-free ring buffer for one writer and N
  * readers, that is to be used to store a sample type T.
@@ -210,7 +212,7 @@ RingBuffer<T, N>::resized(int newSize) const
 
     while (r != w) {
         T value = m_buffer[r];
-        newBuffer->write(&value, 1);
+        newBuffer.write(&value, 1);
         if (++r == m_size) r = 0;
     }
 
@@ -511,4 +513,7 @@ RingBuffer<T, N>::zero(int n)
     return n;
 }
 
+} // end namespace sv
+
+
 #endif // _RINGBUFFER_H_
