@@ -25,6 +25,8 @@
 #include <QStringList>
 #include <QChar>
 
+namespace sv {
+
 class StringBits
 {
 public:
@@ -87,4 +89,6 @@ public:
     static bool isValidUtf8(const std::string &bytes, bool isTruncated);
 };
 
+} // end namespace sv
+
 #endif
