@@ -25,6 +25,8 @@
 
 using namespace std;
 
+namespace sv {
+
 BQAFileReader::BQAFileReader(FileSource source,
 			     DecodeMode decodeMode,
 			     CacheMode mode,
@@ -208,3 +210,5 @@ BQAFileReader::supports(FileSource &source)
             supportsContentType(source.getContentType()));
 }
 
+} // end namespace sv
+
