@@ -21,6 +21,8 @@
 
 #include <bzlib.h>
 
+namespace sv {
+
 class BZipFileDevice : public QIODevice
 {
     Q_OBJECT
@@ -49,4 +51,6 @@ protected:
     bool m_ok;
 };
 
+} // end namespace sv
+
 #endif
