@@ -15,24 +15,26 @@
 
 #include "CSVFormat.h"
 
+//#define DEBUG_COLUMN_QUALITIES 1
+
 #include "base/StringBits.h"
+#include "base/UnitDatabase.h"
+#include "base/Debug.h"
 
 #include <QFile>
 #include <QString>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QStringList>
 #include <QTextStream>
 
 #include <iostream>
 
-#include "base/Debug.h"
-
-//#define DEBUG_COLUMN_QUALITIES 1
+namespace sv {
 
 CSVFormat::CSVFormat(QString path) :
     m_separator(""),
     m_sampleRate(44100),
-    m_windowSize(1024),
+    m_increment(1024),
     m_headerStatus(HeaderUnknown),
     m_allowQuoting(true),
     m_maxExampleCols(0)
@@ -79,7 +81,7 @@ CSVFormat::guessFormatFor(QString path)
         // See comment about line endings in CSVFileReader::load() 
 
         QString chunk = in.readLine();
-        QStringList lines = chunk.split('\r', QString::SkipEmptyParts);
+        QStringList lines = chunk.split('\r', Qt::SkipEmptyParts);
 
         for (int li = 0; li < lines.size(); ++li) {
 
@@ -249,7 +251,7 @@ CSVFormat::guessQualities(QString line, int lineno)
             if (m_columnQualities[i] != ColumnNearEmpty) {
                 couldBeHeader = false;
             } else {
-                headings[i] = list[i].trimmed().toLower();
+                headings[i] = list[i].trimmed();
             }
         }
         if (couldBeHeader) {
@@ -324,6 +326,8 @@ CSVFormat::guessPurposes()
             primaryColumnNo = 1;
         }
     }
+
+    m_columnPossibleUnits.clear();
     
     for (int i = 0; i < m_columnCount; ++i) {
         
@@ -346,8 +350,39 @@ CSVFormat::guessPurposes()
         bool timingColumn = (numeric && increasing);
 
         QString heading;
+        UnitDatabase *udb = UnitDatabase::getInstance();
+
         if (m_columnHeadings.find(i) != m_columnHeadings.end()) {
-            heading = m_columnHeadings[i];
+
+            QString headingAsSeen = m_columnHeadings[i];
+
+            if (headingAsSeen != "") {
+                heading = headingAsSeen.split(' ', Qt::SkipEmptyParts)[0]
+                    .toLower();
+            }
+            
+            QString possibleUnit;
+            if (udb->getUnitId(headingAsSeen, false) >= 0) {
+                possibleUnit = headingAsSeen;
+            } else if (headingAsSeen.contains('(')) {
+                QString test = headingAsSeen;
+                test.replace(QRegularExpression("^[^(]*\\(([^)]+)\\)$"), "\\1");
+                if (test != "") {
+                    SVDEBUG << "Extracted possible unit \"" << test
+                            << "\" from heading \"" << headingAsSeen << "\""
+                            << endl;
+                    if (udb->getUnitId(test, false) >= 0) {
+                        possibleUnit = test;
+                    } else {
+                        SVDEBUG << "(but it isn't recognised)" << endl;
+                    }
+                }
+            } else if (heading == "frequency") {
+                possibleUnit = "Hz";
+            }
+            if (possibleUnit != "") {
+                m_columnPossibleUnits[i] = possibleUnit;
+            }
         }
         
         if (heading == "time" || heading == "frame" ||
@@ -456,6 +491,8 @@ CSVFormat::guessPurposes()
         }
     }
 
+    updateScaleUnits();
+    
     SVDEBUG << "Estimated column purposes: ";
     for (int i = 0; i < m_columnCount; ++i) {
         SVDEBUG << int(m_columnPurposes[i]) << " ";
@@ -464,7 +501,8 @@ CSVFormat::guessPurposes()
 
     SVDEBUG << "Estimated model type: " << m_modelType << endl;
     SVDEBUG << "Estimated timing type: " << m_timingType << endl;
-    SVDEBUG << "Estimated units: " << m_timeUnits << endl;
+    SVDEBUG << "Estimated time units: " << m_timeUnits << endl;
+    SVDEBUG << "Estimated scale units: " << m_scaleUnits << endl;
 }
 
 void
@@ -550,7 +588,7 @@ CSVFormat::setColumnPurposes(QList<ColumnPurpose> cl)
 {
     m_columnPurposes.clear();
     for (int i = 0; in_range_for(cl, i); ++i) {
-        m_columnPurposes[i] = cl[i];
+        setColumnPurpose(i, cl[i]);
     }
 }
 
@@ -568,6 +606,7 @@ void
 CSVFormat::setColumnPurpose(int i, ColumnPurpose p)
 {
     m_columnPurposes[i] = p;
+    updateScaleUnits();
 }
 
 QList<CSVFormat::ColumnQualities>
@@ -583,3 +622,18 @@ CSVFormat::getColumnQualities() const
     }
     return qualities;
 }
+
+void
+CSVFormat::updateScaleUnits()
+{
+    m_scaleUnits = "";
+    for (int i = 0; i < m_columnCount; ++i) {
+        if (m_columnPurposes[i] == ColumnValue &&
+            m_columnPossibleUnits.find(i) != m_columnPossibleUnits.end()) {
+            m_scaleUnits = m_columnPossibleUnits[i];
+        }
+    }
+}
+
+} // end namespace sv
+
