@@ -13,6 +13,8 @@
     COPYING included with this distribution for more information.
 */
 
+#ifndef WITHOUT_LIBSNDFILE // See note in header
+
 #include "DecodingWavFileReader.h"
 
 #include "WavFileReader.h"
@@ -23,6 +25,8 @@
 
 using namespace std;
 
+namespace sv {
+
 DecodingWavFileReader::DecodingWavFileReader(FileSource source,
                                              DecodeMode decodeMode,
                                              CacheMode mode,
@@ -202,3 +206,6 @@ DecodingWavFileReader::supports(FileSource &source)
 }
 
 
+} // end namespace sv
+
+#endif
