@@ -18,6 +18,8 @@
 
 #include <QString>
 
+namespace sv {
+
 class FileFinder 
 {
 public:
@@ -68,6 +70,7 @@ protected:
         void setFileFinder(FileFinder *ff) { m_ff = ff; }
         FileFinder *getFileFinder() const { return m_ff; }
     private:
+        FFContainer() : m_ff(nullptr) { }
         FileFinder *m_ff;
     };
 
@@ -77,6 +80,8 @@ protected:
     }
 };
 
+} // end namespace sv
+
 #endif
 
     
