@@ -25,6 +25,7 @@
 #include <string>
 #include <cstdio>
 #include <algorithm>
+#include <filesystem>
 
 #include "MIDIFileReader.h"
 
@@ -51,6 +52,8 @@ using std::vector;
 using std::map;
 using std::set;
 
+namespace sv {
+
 using namespace MIDIConstants;
 
 //#define MIDI_DEBUG 1
@@ -284,13 +287,8 @@ MIDIFileReader::parseFile()
 #endif
 
     // Open the file
-#ifdef _MSC_VER
-    m_midiFile = new ifstream(m_path.utf16(),
+    m_midiFile = new ifstream(std::filesystem::u8path(m_path.toUtf8().data()),
                               ios::in | ios::binary);
-#else
-    m_midiFile = new ifstream(m_path.toUtf8().data(),
-                              ios::in | ios::binary);
-#endif
 
     if (!*m_midiFile) {
         m_error = "File not found or not readable.";
@@ -1066,4 +1064,6 @@ MIDIFileReader::loadTrack(unsigned int trackToLoad,
     return model;
 }
 
+} // end namespace sv
+
 
