@@ -43,10 +43,10 @@
 
 #include <QFileInfo>
 
-#include <QTextCodec>
-
 using std::string;
 
+namespace sv {
+
 static sv_frame_t DEFAULT_DECODER_DELAY = 529;
 
 MP3FileReader::MP3FileReader(FileSource source, DecodeMode decodeMode, 
@@ -252,7 +252,7 @@ MP3FileReader::loadTag(void *vtag, const char *name)
     }
         
     if (frame->nfields < 2) {
-        cerr << "MP3FileReader::loadTag: WARNING: Not enough fields (" << frame->nfields << ") for \"" << name << "\" in ID3 tag" << endl;
+        SVCERR << "MP3FileReader::loadTag: WARNING: Not enough fields (" << frame->nfields << ") for \"" << name << "\" in ID3 tag" << endl;
         return "";
     }
 
@@ -637,5 +637,7 @@ MP3FileReader::supports(FileSource &source)
             supportsContentType(source.getContentType()));
 }
 
+} // end namespace sv
+
 
 #endif
