@@ -26,6 +26,8 @@
 #include <set>
 #include <atomic>
 
+namespace sv {
+
 class ProgressReporter;
 
 class MP3FileReader : public CodedAudioFileReader
@@ -157,6 +159,8 @@ protected:
     QString loadTag(void *vtag, const char *name);
 };
 
+} // end namespace sv
+
 #endif
 
 #endif
