@@ -17,6 +17,8 @@
 
 #include "data/fileio/FileSource.h"
 
+namespace sv {
+
 class TextTest
 {
 public:
@@ -38,4 +40,6 @@ public:
     static bool isApparentTextDocument(FileSource);
 };
 
+} // end namespace sv
+
 #endif
