@@ -29,6 +29,8 @@
 
 #include "base/Debug.h"
 
+namespace sv {
+
 typedef unsigned char MIDIByte;
 
 namespace MIDIConstants
@@ -237,4 +239,6 @@ protected:
     QString m_message;
 };
 
+} // end namespace sv
+
 #endif
