@@ -25,6 +25,8 @@
 
 class RtMidiIn;
 
+namespace sv {
+
 class MIDIInput : public QObject
 {
     Q_OBJECT
@@ -53,5 +55,7 @@ protected:
     RingBuffer<MIDIEvent *> m_buffer;
 };
 
+} // end namespace sv
+
 #endif
 
