@@ -23,6 +23,8 @@
 #include <QString>
 #include <QStringList>
 
+namespace sv {
+
 class SparseTimeValueModel;
 
 class AlignmentModel : public Model
@@ -117,4 +119,6 @@ protected:
     sv_frame_t performAlignment(const Path &path, sv_frame_t frame) const;
 };
 
+} // end namespace sv
+
 #endif
