@@ -20,6 +20,8 @@
 #include "base/Command.h"
 #include "base/ById.h"
 
+namespace sv {
+
 /**
  * Interface for classes that can be modified through these commands
  */
@@ -173,4 +175,6 @@ protected:
     int m_editableId;
 };
 
+} // end namespace sv
+
 #endif
