@@ -22,6 +22,8 @@
 
 //#define DEBUG_COMPLETION 1
 
+namespace sv {
+
 Model::~Model()
 {
     SVDEBUG << "Model::~Model: " << this << " with id " << getId() << endl;
@@ -215,3 +217,5 @@ Model::toXml(QTextStream &stream, QString indent,
 }
 
 
+} // end namespace sv
+
