@@ -20,8 +20,11 @@
 #include "base/BaseTypes.h"
 
 #include <QStringList>
+#include <QTextStream>
 #include <set>
 
+namespace sv {
+
 struct PathPoint
 {
     PathPoint(sv_frame_t _frame) :
@@ -166,4 +169,6 @@ protected:
 };
 
 
+} // end namespace sv
+
 #endif
