@@ -21,6 +21,8 @@
 
 using namespace std;
 
+namespace sv {
+
 ZoomLevel
 RelativelyFineZoomConstraint::getNearestZoomLevel(ZoomLevel requested,
                                                   RoundingDirection dir) const
@@ -100,3 +102,5 @@ RelativelyFineZoomConstraint::getNearestZoomLevel(ZoomLevel requested,
 }
 
 
+} // end namespace sv
+
