@@ -27,6 +27,8 @@
 
 #include "system/System.h"
 
+namespace sv {
+
 /**
  * A model representing a wiggly-line plot with points at arbitrary
  * intervals of the model resolution.
@@ -197,7 +199,7 @@ public:
         }
 
         float v = e.getValue();
-        if (!ISNAN(v) && !ISINF(v)) {
+        if (!std::isnan(v) && !std::isinf(v)) {
             if (!m_haveExtents || v < m_valueMinimum) {
                 m_valueMinimum = v; allChange = true;
             }
@@ -380,6 +382,8 @@ protected:
     EventSeries m_events;
 };
 
+} // end namespace sv
+
 #endif
 
 
