@@ -15,6 +15,8 @@
 #ifndef SV_OSC_MESSAGE_CALLBACK_H
 #define SV_OSC_MESSAGE_CALLBACK_H
 
+namespace sv {
+
 class OSCMessage;
 
 class OSCMessageCallback {
@@ -23,4 +25,6 @@ public:
     virtual void handleOSCMessage(const OSCMessage &) = 0;
 };
 
+} // end namespace sv
+
 #endif
