@@ -42,6 +42,8 @@
 
 using std::string;
 
+namespace sv {
+
 LADSPAPluginFactory::LADSPAPluginFactory()
 {
 #ifdef HAVE_LRDF
@@ -854,3 +856,5 @@ LADSPAPluginFactory::getPluginCategory(QString identifier)
     return m_taxonomy[identifier];
 }
 
+} // end namespace sv
+
