@@ -25,6 +25,8 @@
 
 #include <QMutex>
 
+namespace sv {
+
 /**
  * FeatureExtractionPluginFactory type for Vamp plugins hosted
  * in-process.
@@ -65,4 +67,6 @@ protected:
     void generateTaxonomy();
 };
 
+} // end namespace sv
+
 #endif
