@@ -25,6 +25,8 @@
 
 #include "plugin/Provider.h"
 
+namespace sv {
+
 class PluginRDFDescription
 {
 public:
@@ -78,5 +80,7 @@ protected:
     bool indexOutputs();
 };
 
+} // end namespace sv
+
 #endif
 
