@@ -36,6 +36,9 @@
 #include <QFile>
 
 #include <iostream>
+#include <mutex>
+
+namespace sv {
 
 using std::vector;
 using std::string;
@@ -56,7 +59,8 @@ PluginRDFIndexer::m_instance = nullptr;
 PluginRDFIndexer *
 PluginRDFIndexer::getInstance() 
 {
-    if (!m_instance) m_instance = new PluginRDFIndexer();
+    static std::once_flag f;
+    std::call_once(f, [&]() { m_instance = new PluginRDFIndexer(); });
     return m_instance;
 }
 
@@ -286,8 +290,6 @@ PluginRDFIndexer::pullURL(QString urlString)
 
 //    SVDEBUG << "PluginRDFIndexer::indexURL(" << urlString << ")" << endl;
 
-    QMutexLocker locker(&m_mutex);
-
     QUrl local = urlString;
 
     if (FileSource::isRemote(urlString) &&
@@ -310,6 +312,7 @@ PluginRDFIndexer::pullURL(QString urlString)
     }
 
     try {
+        QMutexLocker locker(&m_mutex);
         m_index->import(local, BasicStore::ImportIgnoreDuplicates);
     } catch (RDFException &e) {
         SVDEBUG << e.what() << endl;
@@ -323,6 +326,7 @@ PluginRDFIndexer::pullURL(QString urlString)
 bool
 PluginRDFIndexer::reindex()
 {
+    QMutexLocker locker(&m_mutex);
     Triples tt = m_index->match
         (Triple(Node(), Uri("a"), m_index->expand("vamp:Plugin")));
     Nodes plugins = tt.subjects();
@@ -400,3 +404,5 @@ PluginRDFIndexer::reindex()
     
     return addedSomething;
 }
+} // end namespace sv
+
