@@ -26,6 +26,8 @@ namespace Dataquay {
     class BasicStore;
 }
 
+namespace sv {
+
 class PluginRDFIndexer
 {
 public:
@@ -81,5 +83,7 @@ protected:
     static PluginRDFIndexer *m_instance;
 };
 
+} // end namespace sv
+
 #endif
 
