@@ -18,6 +18,8 @@
 
 #include <QString>
 
+namespace sv {
+
 class Model;
 class RDFFeatureWriter;
 
@@ -46,4 +48,6 @@ protected:
     RDFFeatureWriter *m_fw;
 };
 
+} // end namespace sv
+
 #endif
