@@ -24,6 +24,8 @@
 #include "base/BaseTypes.h"
 #include "data/model/Model.h"
 
+namespace sv {
+
 class RDFImporterImpl;
 class ProgressReporter;
 
@@ -70,4 +72,6 @@ protected:
     RDFImporterImpl *m_d;
 };
 
+} // end namespace sv
+
 #endif
