@@ -19,13 +19,16 @@
 #include "ModelTransformer.h"
 #include "plugin/RealTimePluginInstance.h"
 
+namespace sv {
+
 class DenseTimeValueModel;
 
 class RealTimeEffectModelTransformer : public ModelTransformer
 {
 public:
     RealTimeEffectModelTransformer(Input input,
-                                   const Transform &transform);
+                                   const Transform &transform,
+                                   CompletionReporter *reporter = nullptr);
     virtual ~RealTimeEffectModelTransformer();
 
 protected:
@@ -38,5 +41,7 @@ protected:
     int m_outputNo;
 };
 
+} // end namespace sv
+
 #endif
 
