@@ -35,19 +35,25 @@
 #include <set>
 #include <functional>
 
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextStream>
 
 #include "base/Thread.h"
 
 //#define DEBUG_TRANSFORM_FACTORY 1
 
+namespace sv {
+
 TransformFactory *
-TransformFactory::m_instance = new TransformFactory;
+TransformFactory::m_instance = nullptr;
 
 TransformFactory *
 TransformFactory::getInstance()
 {
+    static std::once_flag f;
+    std::call_once(f, [&]() {
+        m_instance = new TransformFactory();
+    });
     return m_instance;
 }
 
@@ -96,6 +102,12 @@ TransformFactory::~TransformFactory()
     }
 }
 
+void
+TransformFactory::restrictTransformTypes(std::set<Transform::Type> types)
+{
+    m_transformTypeRestriction = types;
+}
+
 void
 TransformFactory::startPopulatingInstalledTransforms()
 {
@@ -138,7 +150,8 @@ void
 TransformFactory::UninstalledTransformsPopulateThread::run()
 {
     m_factory->m_populatingSlowly = true;
-    while (!m_factory->havePopulatedInstalledTransforms()) {
+    while (!m_factory->havePopulatedInstalledTransforms() &&
+           !m_factory->m_exiting) {
         sleep(1);
     }
     m_factory->populateUninstalledTransforms();
@@ -152,7 +165,7 @@ TransformFactory::getInstalledTransformDescriptions()
     std::set<TransformDescription> dset;
     for (auto i = m_transforms.begin(); i != m_transforms.end(); ++i) {
 #ifdef DEBUG_TRANSFORM_FACTORY
-        cerr << "inserting transform into set: id = " << i->second.identifier << " (" << i->second.name << ")" << endl;
+        SVCERR << "inserting transform into set: id = " << i->second.identifier << " (" << i->second.name << ")" << endl;
 #endif
         dset.insert(i->second);
     }
@@ -160,7 +173,7 @@ TransformFactory::getInstalledTransformDescriptions()
     TransformList list;
     for (auto i = dset.begin(); i != dset.end(); ++i) {
 #ifdef DEBUG_TRANSFORM_FACTORY
-        cerr << "inserting transform into list: id = " << i->identifier << " (" << i->name << ")" << endl;
+        SVCERR << "inserting transform into list: id = " << i->identifier << " (" << i->name << ")" << endl;
 #endif
         list.push_back(*i);
     }
@@ -197,7 +210,7 @@ TransformFactory::getUninstalledTransformDescriptions()
     for (auto i = m_uninstalledTransforms.begin();
          i != m_uninstalledTransforms.end(); ++i) {
 #ifdef DEBUG_TRANSFORM_FACTORY
-        cerr << "inserting transform into set: id = " << i->second.identifier << endl;
+        SVCERR << "inserting transform into set: id = " << i->second.identifier << endl;
 #endif
         dset.insert(i->second);
     }
@@ -205,7 +218,7 @@ TransformFactory::getUninstalledTransformDescriptions()
     TransformList list;
     for (auto i = dset.begin(); i != dset.end(); ++i) {
 #ifdef DEBUG_TRANSFORM_FACTORY
-        cerr << "inserting transform into uninstalled list: id = " << i->identifier << endl;
+        SVCERR << "inserting transform into uninstalled list: id = " << i->identifier << endl;
 #endif
         list.push_back(*i);
     }
@@ -388,10 +401,32 @@ TransformFactory::populateInstalledTransforms()
         
         TransformDescriptionMap transforms;
 
-        populateFeatureExtractionPlugins(transforms);
-        if (m_exiting) return;
-        populateRealTimePlugins(transforms);
-        if (m_exiting) return;
+        bool wantFeatureExtraction = false;
+        bool wantRealTime = false;
+
+        if (m_transformTypeRestriction.empty()) {
+            wantFeatureExtraction = true;
+            wantRealTime = true;
+        } else {
+            if (m_transformTypeRestriction.find(Transform::FeatureExtraction) !=
+                m_transformTypeRestriction.end()) {
+                wantFeatureExtraction = true;
+            }
+            if (m_transformTypeRestriction.find(Transform::RealTimeEffect) !=
+                m_transformTypeRestriction.end()) {
+                wantRealTime = true;
+            }
+        }
+
+        if (wantFeatureExtraction) {
+            populateFeatureExtractionPlugins(transforms);
+            if (m_exiting) return;
+        }
+
+        if (wantRealTime) {
+            populateRealTimePlugins(transforms);
+            if (m_exiting) return;
+        }
 
         // disambiguate plugins with similar names
 
@@ -434,7 +469,7 @@ TransformFactory::populateInstalledTransforms()
             QString to = td.section(": ", 1);
 
             if (names[tn] > 1) {
-                maker.replace(QRegExp(tr(" [\\(<].*$")), "");
+                maker.replace(QRegularExpression(tr(" [\\(<].*$")), "");
                 tn = QString("%1 [%2]").arg(tn).arg(maker);
             }
 
@@ -478,7 +513,7 @@ TransformFactory::populateFeatureExtractionPlugins(TransformDescriptionMap &tran
         piper_vamp::PluginStaticData psd = factory->getPluginStaticData(pluginId);
 
         if (psd.pluginKey == "") {
-            cerr << "WARNING: TransformFactory::populateInstalledTransforms: No plugin static data available for instance " << pluginId << endl;
+            SVCERR << "WARNING: TransformFactory::populateFeatureExtractionPlugins: No plugin static data available for instance " << pluginId << endl;
             continue;
         }
 
@@ -533,7 +568,7 @@ TransformFactory::populateFeatureExtractionPlugins(TransformDescriptionMap &tran
                                  !psd.parameters.empty());
 
 #ifdef DEBUG_TRANSFORM_FACTORY
-            cerr << "Feature extraction plugin transform: " << transformId << " friendly name: " << friendlyName << endl;
+            SVCERR << "Feature extraction plugin transform: " << transformId << " friendly name: " << friendlyName << endl;
 #endif
 
             transforms[transformId] = 
@@ -544,6 +579,7 @@ TransformFactory::populateFeatureExtractionPlugins(TransformDescriptionMap &tran
                                      friendlyName,
                                      description,
                                      longDescription,
+                                     pluginName,
                                      maker,
 //!!!                                     units,
                                      "",
@@ -559,7 +595,7 @@ TransformFactory::populateRealTimePlugins(TransformDescriptionMap &transforms)
         RealTimePluginFactory::getAllPluginIdentifiers();
     if (m_exiting) return;
 
-    static QRegExp unitRE("[\\[\\(]([A-Za-z0-9/]+)[\\)\\]]$");
+    static QRegularExpression unitRE("[\\[\\(]([A-Za-z0-9/]+)[\\)\\]]$");
 
     for (int i = 0; in_range_for(plugs, i); ++i) {
         
@@ -569,7 +605,7 @@ TransformFactory::populateRealTimePlugins(TransformDescriptionMap &transforms)
             RealTimePluginFactory::instanceFor(pluginId);
 
         if (!factory) {
-            cerr << "WARNING: TransformFactory::populateInstalledTransforms: No real time plugin factory for instance " << pluginId << endl;
+            SVCERR << "WARNING: TransformFactory::populateRealTimePlugins: No real time plugin factory for instance " << pluginId << endl;
             continue;
         }
 
@@ -577,7 +613,7 @@ TransformFactory::populateRealTimePlugins(TransformDescriptionMap &transforms)
             factory->getPluginDescriptor(pluginId);
 
         if (descriptor.name == "") {
-            cerr << "WARNING: TransformFactory::populateInstalledTransforms: Failed to query plugin " << pluginId << endl;
+            SVCERR << "WARNING: TransformFactory::populateRealTimePlugins: Failed to query plugin " << pluginId << endl;
             continue;
         }
         
@@ -610,8 +646,9 @@ TransformFactory::populateRealTimePlugins(TransformDescriptionMap &transforms)
                         .arg(pluginName)
                         .arg(portName);
 
-                    if (unitRE.indexIn(portName) >= 0) {
-                        units = unitRE.cap(1);
+                    auto match = unitRE.match(portName);
+                    if (match.hasMatch()) {
+                        units = match.captured(1);
                     }
 
                 } else if (descriptor.controlOutputPortCount > 1) {
@@ -647,6 +684,7 @@ TransformFactory::populateRealTimePlugins(TransformDescriptionMap &transforms)
                                          userName,
                                          "",
                                          description,
+                                         pluginName,
                                          maker,
                                          units,
                                          configurable);
@@ -679,6 +717,7 @@ TransformFactory::populateRealTimePlugins(TransformDescriptionMap &transforms)
                                          pluginName,
                                          "",
                                          description,
+                                         pluginName,
                                          maker,
                                          "",
                                          configurable);
@@ -1022,7 +1061,7 @@ TransformFactory::setParametersFromPlugin(Transform &transform,
     for (Vamp::PluginBase::ParameterList::const_iterator i = parameters.begin();
          i != parameters.end(); ++i) {
         pmap[i->identifier.c_str()] = plugin->getParameter(i->identifier);
-//        cerr << "TransformFactory::setParametersFromPlugin: parameter "
+//        SVCERR << "TransformFactory::setParametersFromPlugin: parameter "
 //                  << i->identifier << " -> value " <<
 //            pmap[i->identifier.c_str()] << endl;
     }
@@ -1120,10 +1159,10 @@ TransformFactory::makeContextConsistentWithPlugin(Transform &transform,
         }
         if (!transform.getStepSize()) {
             if (domain == Vamp::Plugin::FrequencyDomain) {
-//                cerr << "frequency domain, step = " << blockSize/2 << endl;
+//                SVCERR << "frequency domain, step = " << blockSize/2 << endl;
                 transform.setStepSize(transform.getBlockSize()/2);
             } else {
-//                cerr << "time domain, step = " << blockSize/2 << endl;
+//                SVCERR << "time domain, step = " << blockSize/2 << endl;
                 transform.setStepSize(transform.getBlockSize());
             }
         }
@@ -1301,3 +1340,5 @@ TransformFactory::searchUnadjusted(QStringList keywords)
     return results;
 }
 
+} // end namespace sv
+
