@@ -25,21 +25,21 @@ Colour3DPlotExporter::Colour3DPlotExporter(Sources sources, Parameters params) :
     m_sources(sources),
     m_params(params)
 {
-    SVCERR << "Colour3DPlotExporter::Colour3DPlotExporter: constructed at "
-           << this << endl;
+//    SVCERR << "Colour3DPlotExporter::Colour3DPlotExporter: constructed at "
+//           << this << endl;
 }
 
 Colour3DPlotExporter::~Colour3DPlotExporter()
 {
-    SVCERR << "Colour3DPlotExporter[" << this << "]::~Colour3DPlotExporter"
-           << endl;
+//    SVCERR << "Colour3DPlotExporter[" << this << "]::~Colour3DPlotExporter"
+//           << endl;
 }
 
 void
 Colour3DPlotExporter::discardSources()
 {
-    SVCERR << "Colour3DPlotExporter[" << this << "]::discardSources"
-           << endl;
+//    SVCERR << "Colour3DPlotExporter[" << this << "]::discardSources"
+//           << endl;
     QMutexLocker locker(&m_mutex);
     m_sources.verticalBinLayer = nullptr;
     m_sources.source = {};
@@ -192,7 +192,7 @@ Colour3DPlotExporter::toStringExportRows(DataExportOptions opts,
         
         if (binDisplay == BinDisplay::PeakFrequencies) {
             
-            FFTModel::PeakSet peaks = fftModel->getPeakFrequencies
+            FFTModel::Peaks peaks = fftModel->getPeakFrequencies
                 (FFTModel::AllPeaks, i, minbin, minbin + nbins - 1);
 
             // We don't apply normalisation or gain to the output, but
