@@ -24,10 +24,13 @@
 
 #include "data/model/DenseThreeDimensionalModel.h"
 
-class View;
 class QPainter;
 class QImage;
 
+namespace sv {
+
+class View;
+
 /**
  * This is a view that displays dense 3-D data (time, some sort of
  * binned y-axis range, value) as a colour plot with value mapped to
@@ -94,7 +97,7 @@ public:
                                      int value) const override;
     RangeMapper *getNewPropertyRangeMapper(const PropertyName &) const override;
     void setProperty(const PropertyName &, int value) override;
-    void setProperties(const QXmlAttributes &) override;
+    void setProperties(const LayerAttributes &) override;
     
     void setColourScale(ColourScaleType);
     ColourScaleType getColourScale() const { return m_colourScale; }
@@ -138,15 +141,11 @@ public:
 
     bool hasLightBackground() const override;
 
-    bool getValueExtents(double &min, double &max,
-                         bool &logarithmic, QString &unit) const override;
+    ScaleExtents getVerticalExtents() const override;
 
     bool getDisplayExtents(double &min, double &max) const override;
     bool setDisplayExtents(double min, double max) override;
 
-    bool getYScaleValue(const LayerGeometryProvider *, int /* y */,
-                        double &/* value */, QString &/* unit */) const override;
-
     int getVerticalZoomSteps(int &defaultStep) const override;
     int getCurrentVerticalZoomStep() const override;
     void setVerticalZoomStep(int) override;
@@ -228,4 +227,6 @@ protected:
     void paintWithRenderer(LayerGeometryProvider *v, QPainter &paint, QRect rect) const;
 };
 
+} // end namespace sv
+
 #endif
