@@ -23,6 +23,8 @@
 #include <QPixmap>
 #include <vector>
 
+namespace sv {
+
 class ColourDatabase : public QObject
 {
     Q_OBJECT
@@ -156,8 +158,8 @@ protected:
     
     typedef std::vector<ColourRec> ColourList;
     ColourList m_colours;
-
-    static ColourDatabase m_instance;
 };
 
+} // end namespace sv
+
 #endif
