@@ -19,6 +19,8 @@
 #include <QRect>
 
 class QPainter;
+namespace sv {
+
 class LayerGeometryProvider;
 class HorizontalScaleProvider;
 
@@ -32,4 +34,6 @@ public:
      QPainter &paint, QRect r, bool logarithmic);
 };
 
+} // end namespace sv
+
 #endif
