@@ -21,6 +21,8 @@
 
 class QImage;
 
+namespace sv {
+
 class ImageRegionFinder
 {
 public:
@@ -33,5 +35,7 @@ protected:
     bool similar(QRgb a, QRgb b) const;
 };
 
+} // end namespace sv
+
 #endif
 
