@@ -34,6 +34,14 @@
 
 #include <cmath>
 
+namespace sv {
+
+Layer::ScaleExtents
+Layer::NO_VERTICAL_EXTENTS = {
+    Layer::ScaleApplication::None,
+    CoordinateScale(CoordinateScale::Direction::Vertical, "", false, 0.0, 0.0)
+};
+
 Layer::Layer() :
     m_haveDraggingRect(false),
     m_haveCurrentMeasureRect(false)
@@ -50,18 +58,25 @@ Layer::connectSignals(ModelId modelId)
 {
     auto model = ModelById::get(modelId);
     if (!model) return;
+
+    // Avoid direct connections because of the possibility of mutex
+    // deadlock
     
-    connect(model.get(), SIGNAL(modelChanged(ModelId)),
-            this, SIGNAL(modelChanged(ModelId)));
+    connect(model.get(), &Model::modelChanged,
+            this, &Layer::modelChanged,
+            Qt::QueuedConnection);
 
-    connect(model.get(), SIGNAL(modelChangedWithin(ModelId, sv_frame_t, sv_frame_t)),
-            this, SIGNAL(modelChangedWithin(ModelId, sv_frame_t, sv_frame_t)));
+    connect(model.get(), &Model::modelChangedWithin,
+            this, &Layer::modelChangedWithin,
+            Qt::QueuedConnection);
 
-    connect(model.get(), SIGNAL(completionChanged(ModelId)),
-            this, SIGNAL(modelCompletionChanged(ModelId)));
+    connect(model.get(), &Model::completionChanged,
+            this, &Layer::modelCompletionChanged,
+            Qt::QueuedConnection);
 
-    connect(model.get(), SIGNAL(alignmentCompletionChanged(ModelId)),
-            this, SIGNAL(modelAlignmentCompletionChanged(ModelId)));
+    connect(model.get(), &Model::alignmentCompletionChanged,
+            this, &Layer::modelAlignmentCompletionChanged,
+            Qt::QueuedConnection);
 }
 
 ModelId
@@ -330,7 +345,7 @@ Layer::MeasureRect::toXml(QTextStream &stream, QString indent) const
 }
 
 void
-Layer::addMeasurementRect(const QXmlAttributes &attributes)
+Layer::addMeasurementRect(const LayerAttributes &attributes)
 {
     MeasureRect rect;
     QString fs = attributes.value("startFrame");
@@ -397,15 +412,15 @@ Layer::measureStart(LayerGeometryProvider *v, QMouseEvent *e)
     // once on measureStart, and then not modify it on drag (to avoid
     // drift from repeated conversion back and forth).
     
-    m_draggingRect.pixrect = QRect(e->x(), e->y(), 0, 0);
+    m_draggingRect.pixrect = QRect(e->position().x(), e->position().y(), 0, 0);
 
     if (m_draggingRect.haveFrames) {
-        m_draggingRect.startFrame = v->getFrameForX(e->x());
-        m_draggingRect.endFrame = v->getFrameForX(e->x());
+        m_draggingRect.startFrame = v->getFrameForX(e->position().x());
+        m_draggingRect.endFrame = v->getFrameForX(e->position().x());
     }
 
-    setMeasureRectYCoord(v, m_draggingRect, true, e->y());
-    setMeasureRectYCoord(v, m_draggingRect, false, e->y());
+    setMeasureRectYCoord(v, m_draggingRect, true, e->position().y());
+    setMeasureRectYCoord(v, m_draggingRect, false, e->position().y());
 
     m_haveDraggingRect = true;
 }
@@ -415,15 +430,15 @@ Layer::measureDrag(LayerGeometryProvider *v, QMouseEvent *e)
 {
     if (!m_haveDraggingRect) return;
 
-    m_draggingRect.pixrect.setHeight(e->y() - m_draggingRect.pixrect.y());
+    m_draggingRect.pixrect.setHeight(e->position().y() - m_draggingRect.pixrect.y());
 
     if (m_draggingRect.haveFrames) {
-        m_draggingRect.endFrame = v->getFrameForX(e->x());
+        m_draggingRect.endFrame = v->getFrameForX(e->position().x());
     } else {
-        m_draggingRect.pixrect.setWidth(e->x() - m_draggingRect.pixrect.x());
+        m_draggingRect.pixrect.setWidth(e->position().x() - m_draggingRect.pixrect.x());
     }
 
-    setMeasureRectYCoord(v, m_draggingRect, false, e->y());
+    setMeasureRectYCoord(v, m_draggingRect, false, e->position().y());
 }
 
 void
@@ -625,28 +640,12 @@ Layer::paintMeasurementRect(LayerGeometryProvider *v, QPainter &paint,
 }
 
 bool
-Layer::valueExtentsMatchMine(LayerGeometryProvider *v) const
+Layer::verticalExtentsMatchMine(LayerGeometryProvider *v) const
 {
-    double min, min_;
-    double max, max_;
-    bool logarithmic, logarithmic_;
-    QString unit;
+    CoordinateScale mine = getVerticalExtents().second;
+    CoordinateScale theirs = v->getEffectiveVerticalExtents(mine.getUnit());
 
-    if (!getValueExtents(min_, max_, logarithmic_, unit)) {
-        return false;
-    }
-
-    if (!v->getVisibleExtentsForUnit(unit, min, max, logarithmic)) {
-        return false;
-    }
-
-    if (min != min_ ||
-        max != max_ ||
-        logarithmic != logarithmic_) {
-        return false;
-    }
-
-    return true;
+    return mine.visualRangeMatches(theirs);
 }
 
 void
@@ -711,3 +710,5 @@ Layer::toBriefXml(QTextStream &stream,
         .arg(extraAttributes);
 }
 
+} // end namespace sv
+
