@@ -19,8 +19,10 @@
 #include <QRect>
 
 class QPainter;
+namespace sv {
+
 class LayerGeometryProvider;
-class VerticalScaleLayer;
+class CoordinateScale;
 
 class LogNumericalScale
 {
@@ -28,9 +30,11 @@ public:
     int getWidth(LayerGeometryProvider *v, QPainter &paint);
 
     void paintVertical
-    (LayerGeometryProvider *v, const VerticalScaleLayer *layer,
-     QPainter &paint, int x0, double minlog, double maxlog);
+    (LayerGeometryProvider *v, const CoordinateScale &scale,
+     QPainter &paint, int x0);
 };
 
+} // end namespace sv
+
 #endif
 
