@@ -17,16 +17,18 @@
 #define SV_NOTE_LAYER_H
 
 #include "SingleColourLayer.h"
-#include "VerticalScaleLayer.h"
 
 #include "data/model/NoteModel.h"
 
 #include <QObject>
 #include <QColor>
 
-class View;
 class QPainter;
 
+namespace sv {
+
+class View;
+
 /**
  * Layer for displaying and editing notes, i.e. discrete events with
  * start time, duration, value that represents pitch, and optionally a
@@ -38,8 +40,7 @@ class QPainter;
  * pitch, but the layer always converts to and from Hz behind the
  * scenes.
  */
-class NoteLayer : public SingleColourLayer,
-                  public VerticalScaleLayer
+class NoteLayer : public SingleColourLayer
 {
     Q_OBJECT
 
@@ -108,9 +109,8 @@ public:
 
     int getCompletion(LayerGeometryProvider *) const override;
 
-    bool getValueExtents(double &min, double &max,
-                         bool &log, QString &unit) const override;
-
+    ScaleExtents getVerticalExtents() const override;
+    
     bool getDisplayExtents(double &min, double &max) const override;
     bool setDisplayExtents(double min, double max) override;
 
@@ -140,15 +140,10 @@ public:
     void toXml(QTextStream &stream, QString indent = "",
                        QString extraAttributes = "") const override;
 
-    void setProperties(const QXmlAttributes &attributes) override;
-
-    /// VerticalScaleLayer methods
-    int getYForValue(LayerGeometryProvider *v, double value) const override;
-    double getValueForY(LayerGeometryProvider *v, int y) const override;
-    QString getScaleUnits() const override;
+    void setProperties(const LayerAttributes &attributes) override;
 
 protected:
-    void getScaleExtents(LayerGeometryProvider *, double &min, double &max, bool &log) const;
+    QString getScaleUnits() const;
 
     int getDefaultColourHint(bool dark, bool &impose) override;
 
@@ -189,5 +184,7 @@ protected:
     }
 };
 
+} // end namespace sv
+
 #endif
 
