@@ -44,6 +44,8 @@
 #include <iostream>
 #include <cmath>
 
+namespace sv {
+
 RegionLayer::RegionLayer() :
     SingleColourLayer(),
     m_editing(false),
@@ -302,20 +304,28 @@ RegionLayer::recalcSpacing()
     }
 }
 
-bool
-RegionLayer::getValueExtents(double &min, double &max,
-                           bool &logarithmic, QString &unit) const
+Layer::ScaleExtents
+RegionLayer::getVerticalExtents() const
 {
     auto model = ModelById::getAs<RegionModel>(m_model);
-    if (!model) return false;
-    min = model->getValueMinimum();
-    max = model->getValueMaximum();
-    unit = getScaleUnits();
+    if (!model) return NO_VERTICAL_EXTENTS;
+    
+    double min = model->getValueMinimum();
+    double max = model->getValueMaximum();
+    bool logarithmic = (m_verticalScale == LogScale);
+    QString unit = getScaleUnits();
 
-    if (m_verticalScale == LogScale) logarithmic = true;
+    CoordinateScale scale(CoordinateScale::Direction::Vertical,
+                          unit, logarithmic, min, max);
 
-    return true;
-}
+    if (m_verticalScale == EqualSpaced) {
+        return { Layer::ScaleApplication::Personal, scale };
+    } else if (m_verticalScale == AutoAlignScale) {
+        return { Layer::ScaleApplication::Deferring, scale };
+    } else {
+        return { Layer::ScaleApplication::Normal, scale };
+    }
+}    
 
 bool
 RegionLayer::getDisplayExtents(double &min, double &max) const
@@ -380,12 +390,12 @@ RegionLayer::getPointToDrag(LayerGeometryProvider *v, int x, int y, Event &point
 }
 
 QString
-RegionLayer::getLabelPreceding(sv_frame_t frame) const
+RegionLayer::getLabelAtOrPreceding(sv_frame_t frame) const
 {
     auto model = ModelById::getAs<RegionModel>(m_model);
     if (!model) return "";
     EventVector points = model->getEventsStartingWithin
-        (model->getStartFrame(), frame - model->getStartFrame());
+        (model->getStartFrame(), frame - model->getStartFrame() + 1);
     if (!points.empty()) {
         for (auto i = points.rbegin(); i != points.rend(); ++i) {
             if (i->getLabel() != QString()) {
@@ -598,61 +608,6 @@ RegionLayer::getScaleUnits() const
     else return "";
 }
 
-void
-RegionLayer::getScaleExtents(LayerGeometryProvider *v, double &min, double &max, bool &log) const
-{
-    min = 0.0;
-    max = 0.0;
-    log = false;
-
-    auto model = ModelById::getAs<RegionModel>(m_model);
-    if (!model) return;
-
-    QString queryUnits;
-    queryUnits = getScaleUnits();
-
-    if (m_verticalScale == AutoAlignScale) {
-
-        if (!v->getVisibleExtentsForUnit(queryUnits, min, max, log)) {
-
-            min = model->getValueMinimum();
-            max = model->getValueMaximum();
-
-//            cerr << "RegionLayer[" << this << "]::getScaleExtents: min = " << min << ", max = " << max << ", log = " << log << endl;
-
-        } else if (log) {
-
-            LogRange::mapRange(min, max);
-
-//            cerr << "RegionLayer[" << this << "]::getScaleExtents: min = " << min << ", max = " << max << ", log = " << log << endl;
-
-        }
-
-    } else if (m_verticalScale == EqualSpaced) {
-
-        if (!m_spacingMap.empty()) {
-            SpacingMap::const_iterator i = m_spacingMap.begin();
-            min = i->second;
-            i = m_spacingMap.end();
-            --i;
-            max = i->second;
-//            cerr << "RegionLayer[" << this << "]::getScaleExtents: equal spaced; min = " << min << ", max = " << max << ", log = " << log << endl;
-        }
-
-    } else {
-
-        min = model->getValueMinimum();
-        max = model->getValueMaximum();
-
-        if (m_verticalScale == LogScale) {
-            LogRange::mapRange(min, max);
-            log = true;
-        }
-    }
-
-    if (max == min) max = min + 1.0;
-}
-
 int
 RegionLayer::spacingIndexToY(LayerGeometryProvider *v, int i) const
 {
@@ -678,8 +633,6 @@ RegionLayer::yToSpacingIndex(LayerGeometryProvider *v, int y) const
 int
 RegionLayer::getYForValue(LayerGeometryProvider *v, double val) const
 {
-    double min = 0.0, max = 0.0;
-    bool logarithmic = false;
     int h = v->getPaintHeight();
 
     if (m_verticalScale == EqualSpaced) {
@@ -694,19 +647,10 @@ RegionLayer::getYForValue(LayerGeometryProvider *v, double val) const
 //        SVDEBUG << "RegionLayer::getYForValue: value " << val << " -> i->second " << i->second << " -> y " << y << endl;
         return y;
 
-
     } else {
 
-        getScaleExtents(v, min, max, logarithmic);
-
-//    cerr << "RegionLayer[" << this << "]::getYForValue(" << val << "): min = " << min << ", max = " << max << ", log = " << logarithmic << endl;
-//    cerr << "h = " << h << ", margin = " << margin << endl;
-
-        if (logarithmic) {
-            val = LogRange::map(val);
-        }
-
-        return int(h - ((val - min) * h) / (max - min));
+        CoordinateScale scale = v->getEffectiveVerticalExtentsForLayer(this);
+        return scale.getCoordForValueRounded(v, val);
     }
 }
 
@@ -719,8 +663,6 @@ RegionLayer::getValueForY(LayerGeometryProvider *v, int y) const
 double
 RegionLayer::getValueForY(LayerGeometryProvider *v, int y, int avoid) const
 {
-    double min = 0.0, max = 0.0;
-    bool logarithmic = false;
     int h = v->getPaintHeight();
 
     if (m_verticalScale == EqualSpaced) {
@@ -801,24 +743,23 @@ RegionLayer::getValueForY(LayerGeometryProvider *v, int y, int avoid) const
 
     } else {
 
-        getScaleExtents(v, min, max, logarithmic);
-
-        double val = min + (double(h - y) * double(max - min)) / h;
-
-        if (logarithmic) {
-            val = pow(10.0, val);
-        }
-
-        return val;
+        CoordinateScale scale = v->getEffectiveVerticalExtentsForLayer(this);
+        return scale.getValueForCoord(v, y);
     }
 }
 
 QColor
 RegionLayer::getColourForValue(LayerGeometryProvider *v, double val) const
 {
-    double min, max;
-    bool log;
-    getScaleExtents(v, min, max, log);
+    CoordinateScale scale = v->getEffectiveVerticalExtentsForLayer(this);
+
+    // We could argue for getValueMinimum/Maximum or
+    // getDisplayMinimum/Maximum but we must make sure these match
+    // whatever we use in paintVerticalScale
+    
+    double min = scale.getValueMinimum();
+    double max = scale.getValueMaximum();
+    bool log = scale.isLogarithmic();
 
     if (min > max) std::swap(min, max);
     if (max == min) max = min + 1;
@@ -1054,7 +995,7 @@ RegionLayer::paint(LayerGeometryProvider *v, QPainter &paint, QRect rect) const
 
             int labelX, labelY;
 
-            SVDEBUG << "region label: x " << x << ", nextLabelMinX " << nextLabelMinX << endl;
+//            SVDEBUG << "region label: x " << x << ", nextLabelMinX " << nextLabelMinX << endl;
 
             if (m_plotStyle != PlotSegmentation) {
                 if (drawLabelToLeft) {
@@ -1082,7 +1023,7 @@ RegionLayer::paint(LayerGeometryProvider *v, QPainter &paint, QRect rect) const
             nextLabelMinX = labelX + labelWidth;
             lastLabelY = labelY;
 
-            SVDEBUG << "region label: at " << labelX << "," << labelY << " label " << label << " with nextLabelMinX now " << nextLabelMinX << endl;
+//            SVDEBUG << "region label: at " << labelX << "," << labelY << " label " << label << " with nextLabelMinX now " << nextLabelMinX << endl;
             
             PaintAssistant::drawVisibleText(v, paint, labelX, labelY, label,
                                             PaintAssistant::OutlinedText);
@@ -1121,17 +1062,18 @@ RegionLayer::paintVerticalScale(LayerGeometryProvider *v, bool, QPainter &paint,
     auto model = ModelById::getAs<RegionModel>(m_model);
     if (!model || model->isEmpty()) return;
 
-    QString unit;
-    double min, max;
-    bool logarithmic;
-
     int w = getVerticalScaleWidth(v, false, paint);
 
+    // We are only asked to draw if we are the reference scale, so
+    // don't use getEffectiveVerticalExtentsForLayer here
+    CoordinateScale scale = getVerticalExtents().second;
+
     if (m_plotStyle == PlotSegmentation) {
 
-        getValueExtents(min, max, logarithmic, unit);
+        double min = scale.getValueMinimum();
+        double max = scale.getValueMaximum();
 
-        if (logarithmic) {
+        if (scale.isLogarithmic()) {
             LogRange::mapRange(min, max);
             LogColourScale().paintVertical(v, this, paint, 0, min, max);
         } else {
@@ -1140,20 +1082,18 @@ RegionLayer::paintVerticalScale(LayerGeometryProvider *v, bool, QPainter &paint,
 
     } else {
 
-        getScaleExtents(v, min, max, logarithmic);
-
-        if (logarithmic) {
-            LogNumericalScale().paintVertical(v, this, paint, 0, min, max);
+        if (scale.isLogarithmic()) {
+            LogNumericalScale().paintVertical(v, scale, paint, 0);
         } else {
-            LinearNumericalScale().paintVertical(v, this, paint, 0, min, max);
+            LinearNumericalScale().paintVertical(v, scale, paint, 0);
         }
     }
         
-    if (getScaleUnits() != "") {
+    if (scale.getUnit() != "") {
         int mw = w - 5;
         paint.drawText(5,
                        5 + paint.fontMetrics().ascent(),
-                       TextAbbrev::abbreviate(getScaleUnits(),
+                       TextAbbrev::abbreviate(scale.getUnit(),
                                               paint.fontMetrics(),
                                               mw));
     }
@@ -1165,11 +1105,11 @@ RegionLayer::drawStart(LayerGeometryProvider *v, QMouseEvent *e)
     auto model = ModelById::getAs<RegionModel>(m_model);
     if (!model) return;
 
-    sv_frame_t frame = v->getFrameForX(e->x());
+    sv_frame_t frame = v->getFrameForX(e->position().x());
     if (frame < 0) frame = 0;
     frame = frame / model->getResolution() * model->getResolution();
 
-    double value = getValueForY(v, e->y());
+    double value = getValueForY(v, e->position().y());
 
     m_editingPoint = Event(frame, float(value), 0, "");
     m_originalPoint = m_editingPoint;
@@ -1189,12 +1129,12 @@ RegionLayer::drawDrag(LayerGeometryProvider *v, QMouseEvent *e)
     auto model = ModelById::getAs<RegionModel>(m_model);
     if (!model || !m_editing) return;
 
-    sv_frame_t frame = v->getFrameForX(e->x());
+    sv_frame_t frame = v->getFrameForX(e->position().x());
     if (frame < 0) frame = 0;
     frame = frame / model->getResolution() * model->getResolution();
 
     double newValue = m_editingPoint.getValue();
-    if (m_verticalScale != EqualSpaced) newValue = getValueForY(v, e->y());
+    if (m_verticalScale != EqualSpaced) newValue = getValueForY(v, e->position().y());
 
     sv_frame_t newFrame = m_editingPoint.getFrame();
     sv_frame_t newDuration = frame - newFrame;
@@ -1233,7 +1173,7 @@ RegionLayer::eraseStart(LayerGeometryProvider *v, QMouseEvent *e)
     auto model = ModelById::getAs<RegionModel>(m_model);
     if (!model) return;
 
-    if (!getPointToDrag(v, e->x(), e->y(), m_editingPoint)) return;
+    if (!getPointToDrag(v, e->position().x(), e->position().y(), m_editingPoint)) return;
 
     if (m_editingCommand) {
         finish(m_editingCommand);
@@ -1258,7 +1198,7 @@ RegionLayer::eraseEnd(LayerGeometryProvider *v, QMouseEvent *e)
     m_editing = false;
 
     Event p(0);
-    if (!getPointToDrag(v, e->x(), e->y(), p)) return;
+    if (!getPointToDrag(v, e->position().x(), e->position().y(), p)) return;
     if (p.getFrame() != m_editingPoint.getFrame() ||
         p.getValue() != m_editingPoint.getValue()) return;
 
@@ -1279,7 +1219,7 @@ RegionLayer::editStart(LayerGeometryProvider *v, QMouseEvent *e)
     auto model = ModelById::getAs<RegionModel>(m_model);
     if (!model) return;
 
-    if (!getPointToDrag(v, e->x(), e->y(), m_editingPoint)) {
+    if (!getPointToDrag(v, e->position().x(), e->position().y(), m_editingPoint)) {
         return;
     }
 
@@ -1294,8 +1234,8 @@ RegionLayer::editStart(LayerGeometryProvider *v, QMouseEvent *e)
     }
 
     m_editing = true;
-    m_dragStartX = e->x();
-    m_dragStartY = e->y();
+    m_dragStartX = e->position().x();
+    m_dragStartY = e->position().y();
     recalcSpacing();
 }
 
@@ -1305,8 +1245,8 @@ RegionLayer::editDrag(LayerGeometryProvider *v, QMouseEvent *e)
     auto model = ModelById::getAs<RegionModel>(m_model);
     if (!model || !m_editing) return;
 
-    int xdist = e->x() - m_dragStartX;
-    int ydist = e->y() - m_dragStartY;
+    int xdist = e->position().x() - m_dragStartX;
+    int ydist = e->position().y() - m_dragStartY;
     int newx = m_dragPointX + xdist;
     int newy = m_dragPointY + ydist;
 
@@ -1372,7 +1312,9 @@ RegionLayer::editOpen(LayerGeometryProvider *v, QMouseEvent *e)
     if (!model) return false;
 
     Event region(0);
-    if (!getPointToDrag(v, e->x(), e->y(), region)) return false;
+    if (!getPointToDrag(v, e->position().x(), e->position().y(), region)) {
+        return false;
+    }
 
     ItemEditDialog *dialog = new ItemEditDialog
         (model->getSampleRate(),
@@ -1609,7 +1551,7 @@ RegionLayer::toXml(QTextStream &stream,
 }
 
 void
-RegionLayer::setProperties(const QXmlAttributes &attributes)
+RegionLayer::setProperties(const LayerAttributes &attributes)
 {
     SingleColourLayer::setProperties(attributes);
 
@@ -1636,3 +1578,5 @@ RegionLayer::setProperties(const QXmlAttributes &attributes)
 }
 
 
+} // end namespace sv
+
