@@ -15,6 +15,7 @@
 #include "ScrollableImageCache.h"
 
 #include "base/HitCount.h"
+#include "base/Debug.h"
 
 #include <iostream>
 using namespace std;
@@ -23,6 +24,32 @@ using namespace std;
 
 namespace sv {
 
+ScrollableImageCache::ScrollableImageCache() :
+    m_validLeft(0),
+    m_validWidth(0),
+    m_startFrame(0)
+{
+#ifdef DEBUG_SCROLLABLE_IMAGE_CACHE
+    SVCERR << "ScrollableImageCache[" << this << "]::ScrollableImageCache" << endl;
+#endif
+}
+
+ScrollableImageCache::~ScrollableImageCache()
+{
+#ifdef DEBUG_SCROLLABLE_IMAGE_CACHE
+    SVCERR << "ScrollableImageCache[" << this << "]::~ScrollableImageCache" << endl;
+#endif
+}
+
+void
+ScrollableImageCache::invalidate()
+{
+#ifdef DEBUG_SCROLLABLE_IMAGE_CACHE
+    SVCERR << "ScrollableImageCache[" << this << "]::invalidate" << endl;
+#endif
+    m_validWidth = 0;
+}
+
 void
 ScrollableImageCache::scrollTo(const LayerGeometryProvider *v,
                                sv_frame_t newStartFrame)
@@ -33,7 +60,7 @@ ScrollableImageCache::scrollTo(const LayerGeometryProvider *v,
               v->getXForFrame(newStartFrame));
     
 #ifdef DEBUG_SCROLLABLE_IMAGE_CACHE
-    cerr << "ScrollableImageCache::scrollTo: start frame " << m_startFrame
+    SVCERR << "ScrollableImageCache[" << this << "]::scrollTo: start frame " << m_startFrame
          << " -> " << newStartFrame << ", dx = " << dx << endl;
 #endif
 
@@ -117,9 +144,9 @@ ScrollableImageCache::adjustToTouchValidArea(int &left, int &width,
                                              bool &isLeftOfValidArea) const
 {
 #ifdef DEBUG_SCROLLABLE_IMAGE_CACHE
-    cerr << "ScrollableImageCache::adjustToTouchValidArea: left " << left
+    SVCERR << "ScrollableImageCache[" << this << "]::adjustToTouchValidArea: left " << left
          << ", width " << width << endl;
-    cerr << "ScrollableImageCache: my left " << m_validLeft
+    SVCERR << "ScrollableImageCache[" << this << "]: my left " << m_validLeft
          << ", width " << m_validWidth << " so right " << (m_validLeft + m_validWidth) << endl;
 #endif
     if (left < m_validLeft) {
@@ -128,7 +155,7 @@ ScrollableImageCache::adjustToTouchValidArea(int &left, int &width,
             width = m_validLeft - left;
         }
 #ifdef DEBUG_SCROLLABLE_IMAGE_CACHE
-        cerr << "ScrollableImageCache: we're left of valid area, adjusted width to " << width << endl;
+        SVCERR << "ScrollableImageCache[" << this << "]: we're left of valid area, adjusted width to " << width << endl;
 #endif
     } else {
         isLeftOfValidArea = false;
@@ -136,7 +163,7 @@ ScrollableImageCache::adjustToTouchValidArea(int &left, int &width,
         left = m_validLeft + m_validWidth;
         if (width < 0) width = 0;
 #ifdef DEBUG_SCROLLABLE_IMAGE_CACHE
-        cerr << "ScrollableImageCache: we're right of valid area, adjusted left to " << left << ", width to " << width << endl;
+        SVCERR << "ScrollableImageCache[" << this << "]: we're right of valid area, adjusted left to " << left << ", width to " << width << endl;
 #endif
     }
 }
@@ -149,23 +176,23 @@ ScrollableImageCache::drawImage(int left,
                                 int imageWidth)
 {
     if (image.height() != m_image.height()) {
-        cerr << "ScrollableImageCache::drawImage: ERROR: Supplied image height "
+        SVCERR << "ScrollableImageCache[" << this << "]::drawImage: ERROR: Supplied image height "
              << image.height() << " does not match cache height "
              << m_image.height() << endl;
         throw std::logic_error("Image height must match cache height in ScrollableImageCache::drawImage");
     }
     if (left < 0 || width < 0 || left + width > m_image.width()) {
-        cerr << "ScrollableImageCache::drawImage: ERROR: Target area (left = "
+        SVCERR << "ScrollableImageCache[" << this << "]::drawImage: ERROR: Target area (left = "
              << left << ", width = " << width << ", so right = " << left + width
              << ") out of bounds for cache of width " << m_image.width() << endl;
         throw std::logic_error("Target area out of bounds in ScrollableImageCache::drawImage");
     }
     if (imageLeft < 0 || imageWidth < 0 ||
         imageLeft + imageWidth > image.width()) {
-        cerr << "ScrollableImageCache::drawImage: ERROR: Source area (left = "
-             << imageLeft << ", width = " << imageWidth << ", so right = "
-             << imageLeft + imageWidth << ") out of bounds for image of "
-             << "width " << image.width() << endl;
+        SVCERR << "ScrollableImageCache[" << this << "]::drawImage: ERROR: Source area (left = "
+               << imageLeft << ", width = " << imageWidth << ", so right = "
+               << imageLeft + imageWidth << ") out of bounds for image of "
+               << "width " << image.width() << endl;
         throw std::logic_error("Source area out of bounds in ScrollableImageCache::drawImage");
     }
         
