@@ -18,6 +18,8 @@
 
 #include "base/Command.h"
 
+namespace sv {
+
 class ShowLayerCommand : public Command
 {
 public:
@@ -39,4 +41,6 @@ protected:
     QString m_name;
 };
 
+} // end namespace sv
+
 #endif
