@@ -31,6 +31,8 @@
 #include <QTextStream>
 
 
+namespace sv {
+
 SliceLayer::SliceLayer() :
     m_binAlignment(BinsSpanScalePoints),
     m_colourMap(int(ColourMapper::Ice)),
@@ -739,19 +741,14 @@ SliceLayer::paint(LayerGeometryProvider *v, QPainter &paint, QRect rect) const
 int
 SliceLayer::getVerticalScaleWidth(LayerGeometryProvider *, bool, QPainter &paint) const
 {
-    // Qt 5.13 deprecates QFontMetrics::width(), but its suggested
-    // replacement (horizontalAdvance) was only added in Qt 5.11
-    // which is too new for us
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-
     int width;
     if (m_energyScale == LinearScale || m_energyScale == AbsoluteScale) {
-        width = std::max(paint.fontMetrics().width("0.0") + 13,
-                         paint.fontMetrics().width("x10-10"));
+        width = std::max(paint.fontMetrics().horizontalAdvance("0.0") + 13,
+                         paint.fontMetrics().horizontalAdvance("x10-10"));
     } else {
-        width = std::max(std::max(paint.fontMetrics().width(tr("0dB")),
-                                  paint.fontMetrics().width(tr("-160"))),
-                         paint.fontMetrics().width(tr("-Inf"))) + 13;
+        width = std::max(std::max(paint.fontMetrics().horizontalAdvance(tr("0dB")),
+                                  paint.fontMetrics().horizontalAdvance(tr("-160"))),
+                         paint.fontMetrics().horizontalAdvance(tr("-Inf"))) + 13;
     }
     return width;
 }
@@ -805,7 +802,7 @@ SliceLayer::paintVerticalScale(LayerGeometryProvider *v, bool, QPainter &paint,
         QString a = tr("x10");
         QString b = QString("%1").arg(-log);
         paint.drawText(3, 8 + paint.fontMetrics().ascent(), a);
-        paint.drawText(3 + paint.fontMetrics().width(a),
+        paint.drawText(3 + paint.fontMetrics().horizontalAdvance(a),
                        3 + paint.fontMetrics().ascent(), b);
     }
 }
@@ -1213,7 +1210,7 @@ SliceLayer::toXml(QTextStream &stream,
 }
 
 void
-SliceLayer::setProperties(const QXmlAttributes &attributes)
+SliceLayer::setProperties(const LayerAttributes &attributes)
 {
     bool ok = false;
 
@@ -1262,21 +1259,32 @@ SliceLayer::setProperties(const QXmlAttributes &attributes)
     if (ok && alsoOk) setDisplayExtents(min, max);
 }
 
-bool
-SliceLayer::getValueExtents(double &min, double &max, bool &logarithmic,
-                            QString &unit) const
+Layer::ScaleExtents
+SliceLayer::getVerticalExtents() const
 {
     auto sliceableModel =
         ModelById::getAs<DenseThreeDimensionalModel>(m_sliceableModel);
-    if (!sliceableModel) return false;
+    if (!sliceableModel) return NO_VERTICAL_EXTENTS;
     
-    min = 0;
-    max = double(sliceableModel->getHeight());
+    double min = 0;
+    double max = double(sliceableModel->getHeight());
+    bool logarithmic = (m_binScale == BinScale::LogBins);
+    QString unit = "";
 
-    logarithmic = (m_binScale == BinScale::LogBins);
-    unit = "";
+    CoordinateScale scale(CoordinateScale::Direction::Vertical,
+                          unit, logarithmic, min, max);
 
-    return true;
+    if (m_minbin < m_maxbin) {
+        if (m_minbin > 0) {
+            min = m_minbin;
+        }
+        if (m_maxbin < max) {
+            max = m_maxbin;
+        }
+        scale = scale.withDisplayExtents(min, max);
+    }
+
+    return { Layer::ScaleApplication::Normal, scale };
 }
 
 bool
@@ -1396,3 +1404,5 @@ SliceLayer::zoomToRegion(const LayerGeometryProvider *v, QRect rect)
     setDisplayExtents(floor(bin0), ceil(bin1));
 }
 
+} // end namespace sv
+
