@@ -26,6 +26,8 @@
 
 #include <QColor>
 
+namespace sv {
+
 class SliceLayer : public SingleColourLayer
 {
     Q_OBJECT
@@ -62,10 +64,9 @@ public:
                                           int value) const override;
     RangeMapper *getNewPropertyRangeMapper(const PropertyName &) const override;
     void setProperty(const PropertyName &, int value) override;
-    void setProperties(const QXmlAttributes &) override;
+    void setProperties(const LayerAttributes &) override;
 
-    bool getValueExtents(double &min, double &max,
-                         bool &logarithmic, QString &unit) const override;
+    ScaleExtents getVerticalExtents() const override;
 
     bool getDisplayExtents(double &min, double &max) const override;
     bool setDisplayExtents(double min, double max) override;
@@ -201,4 +202,6 @@ protected:
     mutable std::vector<float>  m_values;
 };
 
+} // end namespace sv
+
 #endif
