@@ -22,9 +22,12 @@
 #include <QObject>
 #include <QColor>
 
-class View;
 class QPainter;
 
+namespace sv {
+
+class View;
+
 class TextLayer : public SingleColourLayer
 {
     Q_OBJECT
@@ -80,15 +83,14 @@ public:
 
     int getCompletion(LayerGeometryProvider *) const override;
 
-    bool getValueExtents(double &min, double &max,
-                                 bool &logarithmic, QString &unit) const override;
+    ScaleExtents getVerticalExtents() const override;
 
     int getVerticalScaleWidth(LayerGeometryProvider *, bool, QPainter &) const override { return 0; }
 
     void toXml(QTextStream &stream, QString indent = "",
                        QString extraAttributes = "") const override;
 
-    void setProperties(const QXmlAttributes &attributes) override;
+    void setProperties(const LayerAttributes &attributes) override;
 
 protected:
     int getYForHeight(LayerGeometryProvider *v, double height) const;
@@ -113,5 +115,7 @@ protected:
     }
 };
 
+} // end namespace sv
+
 #endif
 
