@@ -34,6 +34,8 @@
 //#define DEBUG_TIME_RULER_LAYER 1
 
 
+namespace sv {
+
 TimeRulerLayer::TimeRulerLayer() :
     SingleColourLayer(),
     m_labelHeight(LabelTop)
@@ -149,12 +151,7 @@ TimeRulerLayer::getMajorTickUSec(LayerGeometryProvider *v,
         endFrame = startFrame + 1;
     }
 
-    // Qt 5.13 deprecates QFontMetrics::width(), but its suggested
-    // replacement (horizontalAdvance) was only added in Qt 5.11
-    // which is too new for us
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-
-    int exampleWidth = QFontMetrics(QFont()).width("10:42.987654");
+    int exampleWidth = QFontMetrics(QFont()).horizontalAdvance("10:42.987654");
     int minPixelSpacing = v->getXForViewX(exampleWidth);
 
     RealTime rtStart = RealTime::frame2RealTime(startFrame, sampleRate);
@@ -165,7 +162,7 @@ TimeRulerLayer::getMajorTickUSec(LayerGeometryProvider *v,
     RealTime rtGap = (rtEnd - rtStart) / count;
 
 #ifdef DEBUG_TIME_RULER_LAYER
-    SVCERR << "zoomLevel = " << v->getZoomLevel()
+    SVCERR << "zoomLevel = " << v->getRoundedZoomLevel()
            << ", startFrame = " << startFrame << ", endFrame = " << endFrame
            << ", rtStart = " << rtStart << ", rtEnd = " << rtEnd
            << ", paint width = " << v->getPaintWidth()
@@ -223,7 +220,7 @@ TimeRulerLayer::getXForUSec(LayerGeometryProvider *v, double us) const
     sv_frame_t frame = sv_frame_t(floor(dframe + eps));
     int x;
 
-    ZoomLevel zoom = v->getZoomLevel();
+    ZoomLevel zoom = v->getRoundedZoomLevel();
 
     if (zoom.zone == ZoomLevel::FramesPerPixel) {
             
@@ -293,7 +290,7 @@ TimeRulerLayer::paint(LayerGeometryProvider *v, QPainter &paint, QRect rect) con
 
     int minPixelSpacing = v->getXForViewX(50);
     sv_frame_t incFrame = lrint((double(incus) * sampleRate) / 1000000);
-    int incX = int(round(v->getZoomLevel().framesToPixels(double(incFrame))));
+    int incX = int(round(v->getRoundedZoomLevel().framesToPixels(double(incFrame))));
     int ticks = 10;
     if (incX < minPixelSpacing * 2) {
         ticks = quarter ? 4 : 5;
@@ -336,7 +333,7 @@ TimeRulerLayer::paint(LayerGeometryProvider *v, QPainter &paint, QRect rect) con
             QString text(QString::fromStdString(rt.toText()));
             
             QFontMetrics metrics = paint.fontMetrics();
-            int tw = metrics.width(text);
+            int tw = metrics.horizontalAdvance(text);
 
             if (tw < 50 &&
                 (x < rect.x() - tw/2 ||
@@ -443,8 +440,10 @@ TimeRulerLayer::toXml(QTextStream &stream,
 }
 
 void
-TimeRulerLayer::setProperties(const QXmlAttributes &attributes)
+TimeRulerLayer::setProperties(const LayerAttributes &attributes)
 {
     SingleColourLayer::setProperties(attributes);
 }
 
+} // end namespace sv
+
