@@ -21,9 +21,12 @@
 #include <QRect>
 #include <QColor>
 
+class QPainter;
+
+namespace sv {
+
 class View;
 class Model;
-class QPainter;
 
 class TimeRulerLayer : public SingleColourLayer
 {
@@ -48,10 +51,10 @@ public:
         return ColourIrrelevant;
     }
 
-    bool getValueExtents(double &, double &, bool &, QString &) const override {
-        return false;
+    ScaleExtents getVerticalExtents() const override {
+        return NO_VERTICAL_EXTENTS;
     }
-
+    
     QString getLayerPresentationName() const override;
 
     int getVerticalScaleWidth(LayerGeometryProvider *, bool, QPainter &) const override { return 0; }
@@ -59,7 +62,7 @@ public:
     void toXml(QTextStream &stream, QString indent = "",
                        QString extraAttributes = "") const override;
 
-    void setProperties(const QXmlAttributes &attributes) override;
+    void setProperties(const LayerAttributes &attributes) override;
 
     bool canExistWithoutModel() const override { return true; }
 
@@ -73,4 +76,6 @@ protected:
     int getXForUSec(LayerGeometryProvider *, double usec) const;
 };
 
+} // end namespace sv
+
 #endif
