@@ -17,7 +17,6 @@
 #define SV_TIME_VALUE_LAYER_H
 
 #include "SingleColourLayer.h"
-#include "VerticalScaleLayer.h"
 #include "ColourScaleLayer.h"
 
 #include "data/model/SparseTimeValueModel.h"
@@ -25,11 +24,13 @@
 #include <QObject>
 #include <QColor>
 
-class View;
 class QPainter;
 
+namespace sv {
+
+class View;
+
 class TimeValueLayer : public SingleColourLayer, 
-                       public VerticalScaleLayer, 
                        public ColourScaleLayer
 {
     Q_OBJECT
@@ -43,7 +44,7 @@ public:
     void paintVerticalScale(LayerGeometryProvider *v, bool, QPainter &paint, QRect rect) const override;
 
     QString getFeatureDescription(LayerGeometryProvider *v, QPoint &) const override;
-    QString getLabelPreceding(sv_frame_t) const override;
+    QString getLabelAtOrPreceding(sv_frame_t) const override;
 
     bool snapToFeatureFrame(LayerGeometryProvider *v, sv_frame_t &frame,
                             int &resolution,
@@ -123,6 +124,9 @@ public:
     void setShowDerivative(bool);
     bool getShowDerivative() const { return m_derivative; }
 
+    void setPermitValueEditOfSegmentation(bool);
+    bool getPermitValueEditOfSegmentation() const { return m_permitValueEditOfSegmentation; }
+    
     bool isLayerScrollable(const LayerGeometryProvider *v) const override;
 
     bool isLayerEditable() const override { return true; }
@@ -131,12 +135,14 @@ public:
 
     bool needsTextLabelHeight() const override;
 
-    bool getValueExtents(double &min, double &max,
-                                 bool &logarithmic, QString &unit) const override;
+    ScaleExtents getVerticalExtents() const override;
 
     bool getDisplayExtents(double &min, double &max) const override;
     bool setDisplayExtents(double min, double max) override;
 
+    void overrideHighlightForPointsAt(sv_frame_t);
+    void removeOverrideHighlight();
+
     int getVerticalZoomSteps(int &defaultStep) const override;
     int getCurrentVerticalZoomStep() const override;
     void setVerticalZoomStep(int) override;
@@ -145,7 +151,7 @@ public:
     void toXml(QTextStream &stream, QString indent = "",
                        QString extraAttributes = "") const override;
 
-    void setProperties(const QXmlAttributes &attributes) override;
+    void setProperties(const LayerAttributes &attributes) override;
 
     /// Override from SingleColourLayer
     ColourSignificance getLayerColourSignificance() const override {
@@ -164,15 +170,15 @@ public:
             return SingleColourLayer::hasLightBackground();
         }
     }
-
-    /// VerticalScaleLayer and ColourScaleLayer methods
-    int getYForValue(LayerGeometryProvider *, double value) const override;
-    double getValueForY(LayerGeometryProvider *, int y) const override;
-    QString getScaleUnits() const override;
+    
+    /// ColourScaleLayer method
     QColor getColourForValue(LayerGeometryProvider *v, double value) const override;
 
+signals:
+    void frameIlluminated(sv_frame_t);
+    
 protected:
-    void getScaleExtents(LayerGeometryProvider *, double &min, double &max, bool &log) const;
+    QString getScaleUnits() const override; // ColourScaleLayer
     bool shouldAutoAlign() const;
 
     EventVector getLocalPoints(LayerGeometryProvider *v, int) const;
@@ -191,7 +197,10 @@ protected:
     bool m_drawSegmentDivisions;
     bool m_fillSegments;
     bool m_derivative;
+    bool m_permitValueEditOfSegmentation;
     bool m_propertiesExplicitlySet;
+    bool m_overrideHighlight;
+    sv_frame_t m_highlightOverrideFrame;
 
     mutable double m_scaleMinimum;
     mutable double m_scaleMaximum;
@@ -202,5 +211,7 @@ protected:
     }
 };
 
+} // end namespace sv
+
 #endif
 
