@@ -18,6 +18,8 @@
 
 #include "View.h"
 
+namespace sv {
+
 class AlignmentView : public View
 {
     Q_OBJECT
@@ -65,4 +67,6 @@ protected:
     sv_frame_t m_rightmostAbove;
 };
 
+} // end namespace sv
+
 #endif
