@@ -176,16 +176,18 @@ PaneStack::addPane(int index)
 
     frame->setLayout(layout);
 
+    int indexInWidgets = mapInsertionIndexToWidgets(index);
+    
     if (m_options & int(Option::NoUserResize)) {
         if (index >= 0) {
-            m_autoResizeLayout->insertWidget(index, frame);
+            m_autoResizeLayout->insertWidget(indexInWidgets, frame);
         } else {
             m_autoResizeLayout->addWidget(frame);
         }
         frame->adjustSize();
     } else {
         if (index >= 0) {
-            m_splitter->insertWidget(index, frame);
+            m_splitter->insertWidget(indexInWidgets, frame);
         } else {
             m_splitter->addWidget(frame);
         }
@@ -219,6 +221,51 @@ PaneStack::addPane(int index)
     return pane;
 }
 
+int
+PaneStack::mapInsertionIndexToWidgets(int index) const
+{
+    // The index used to refer to pane position within the stack is
+    // among visible panes only. But hidden panes are still there in
+    // the stack or layout, so when we want to use its insertWidget
+    // method we need to adjust the index to skip hidden widgets
+
+    if (index <= 0) {
+        return index;
+    }
+
+    int counted = 0;
+
+    if (m_options & int(Option::NoUserResize)) {
+
+        // We're using m_autoResizeLayout, a QVBoxLayout
+        
+        for (int i = 0; i < m_autoResizeLayout->count(); ++i) {
+            if (counted == index) return i;
+            auto w = dynamic_cast<QWidgetItem *>(m_autoResizeLayout->itemAt(i));
+            if (w && dynamic_cast<QFrame *>(w->widget()) &&
+                w->widget()->isVisible()) {
+                ++counted;
+            }
+        }
+        return m_autoResizeLayout->count();
+
+    } else {
+
+        // We're using m_splitter, a QSplitter
+            
+        for (int i = 0; i < m_splitter->count(); ++i) {
+            if (counted == index) {
+                return i;
+            }
+            if (dynamic_cast<QFrame *>(m_splitter->widget(i)) &&
+                m_splitter->widget(i)->isVisible()) {
+                ++counted;
+            }
+        }
+        return m_splitter->count();
+    }
+}
+
 void
 PaneStack::relinkAlignmentViews()
 {
@@ -765,13 +812,13 @@ PaneStack::sizePanesEqually()
     if (m_options & int(Option::NoUserResize)) {
         return;
     }
-    
+
     QList<int> sizes = m_splitter->sizes();
     if (sizes.empty()) return;
 
     int count = sizes.size();
 
-    int fixed = 0, variable = 0, total = 0;
+    int variable = 0, total = 0;
     int varicount = 0;
 
     for (int i = 0; i < count; ++i) {
@@ -780,13 +827,17 @@ PaneStack::sizePanesEqually()
 
     variable = total;
 
+    int j = 0; // index into m_panes, which contains only visible panes
+    
     for (int i = 0; i < count; ++i) {
-        int minh = m_panes[i].pane->minimumSize().height();
-        if (minh == m_panes[i].pane->maximumSize().height()) {
-            fixed += minh;
-            variable -= minh;
-        } else {
-            varicount++;
+        if (m_splitter->widget(i)->isVisible()) {
+            int minh = m_panes[j].pane->minimumSize().height();
+            if (minh == m_panes[j].pane->maximumSize().height()) {
+                variable -= minh;
+            } else {
+                varicount++;
+            }
+            ++j;
         }
     }
 
@@ -797,17 +848,24 @@ PaneStack::sizePanesEqually()
     int each = (varicount > 0 ? (variable / varicount) : 0);
     int remaining = total;
 
+    j = 0;
+    
     for (int i = 0; i < count; ++i) {
         if (i == count - 1) {
             sizes.push_back(remaining);
         } else {
-            int minh = m_panes[i].pane->minimumSize().height();
-            if (minh == m_panes[i].pane->maximumSize().height()) {
-                sizes.push_back(minh);
-                remaining -= minh;
+            if (m_splitter->widget(i)->isVisible()) {
+                int minh = m_panes[j].pane->minimumSize().height();
+                if (minh == m_panes[j].pane->maximumSize().height()) {
+                    sizes.push_back(minh);
+                    remaining -= minh;
+                } else {
+                    sizes.push_back(each);
+                    remaining -= each;
+                }
+                ++j;
             } else {
-                sizes.push_back(each);
-                remaining -= each;
+                sizes.push_back(0);
             }
         }
     }
