@@ -29,6 +29,9 @@ class QVBoxLayout;
 class QSplitter;
 class QGridLayout;
 class QPushButton;
+
+namespace sv {
+
 class View;
 class Pane;
 class Layer;
@@ -58,7 +61,7 @@ public:
               ViewManager *viewManager,
               Options options = 0);
 
-    Pane *addPane(); // I own the returned value
+    Pane *addPane(int atIndex = -1); // Index is among visible panes; I own returned value
     void deletePane(Pane *pane); // Deletes the pane, but _not_ its layers
 
     int getPaneCount() const; // Returns only count of visible panes
@@ -163,8 +166,12 @@ protected:
     void resizeEvent(QResizeEvent *) override;
     void adjustAlignmentViewHeights(int forMyHeight);
 
+    int mapInsertionIndexToWidgets(int index) const;
+    
     LayoutStyle m_layoutStyle;
 };
 
+} // end namespace sv
+
 #endif
 
