@@ -28,10 +28,10 @@
 #include <QApplication>
 #include <QStyleFactory>
 
-#include <iostream>
-
 //#define DEBUG_VIEW_MANAGER 1
 
+namespace sv {
+
 ViewManager::ViewManager() :
     m_playSource(nullptr),
     m_recordTarget(nullptr),
@@ -142,7 +142,7 @@ sv_frame_t
 ViewManager::getGlobalCentreFrame() const
 {
 #ifdef DEBUG_VIEW_MANAGER
-    cerr << "ViewManager::getGlobalCentreFrame: returning " << m_globalCentreFrame << endl;
+    SVCERR << "ViewManager::getGlobalCentreFrame: returning " << m_globalCentreFrame << endl;
 #endif
     return m_globalCentreFrame;
 }
@@ -151,7 +151,7 @@ void
 ViewManager::setGlobalCentreFrame(sv_frame_t f)
 {
 #ifdef DEBUG_VIEW_MANAGER
-    cerr << "ViewManager::setGlobalCentreFrame to " << f << endl;
+    SVCERR << "ViewManager::setGlobalCentreFrame to " << f << endl;
 #endif
     m_globalCentreFrame = f;
     emit globalCentreFrameChanged(f);
@@ -161,7 +161,7 @@ ZoomLevel
 ViewManager::getGlobalZoom() const
 {
 #ifdef DEBUG_VIEW_MANAGER
-    cerr << "ViewManager::getGlobalZoom: returning " << m_globalZoom << endl;
+    SVCERR << "ViewManager::getGlobalZoom: returning " << m_globalZoom << endl;
 #endif
     return m_globalZoom;
 }
@@ -172,16 +172,16 @@ ViewManager::getPlaybackFrame() const
     if (isRecording()) {
         m_playbackFrame = m_recordTarget->getRecordDuration();
 #ifdef DEBUG_VIEW_MANAGER
-        cout << "ViewManager::getPlaybackFrame(recording) -> " << m_playbackFrame << endl;
+        SVCERR << "ViewManager::getPlaybackFrame(recording) -> " << m_playbackFrame << endl;
 #endif
     } else if (isPlaying()) {
         m_playbackFrame = m_playSource->getCurrentPlayingFrame();
 #ifdef DEBUG_VIEW_MANAGER
-        cout << "ViewManager::getPlaybackFrame(playing) -> " << m_playbackFrame << endl;
+        SVCERR << "ViewManager::getPlaybackFrame(playing) -> " << m_playbackFrame << endl;
 #endif
     } else {
 #ifdef DEBUG_VIEW_MANAGER
-        cout << "ViewManager::getPlaybackFrame(not playing) -> " << m_playbackFrame << endl;
+        SVCERR << "ViewManager::getPlaybackFrame(not playing) -> " << m_playbackFrame << endl;
 #endif
     }
     return m_playbackFrame;
@@ -191,7 +191,7 @@ void
 ViewManager::setPlaybackFrame(sv_frame_t f)
 {
 #ifdef DEBUG_VIEW_MANAGER
-    cerr << "ViewManager::setPlaybackFrame(" << f << ")" << endl;
+    SVCERR << "ViewManager::setPlaybackFrame(" << f << ")" << endl;
 #endif
     if (f < 0) f = 0;
     if (m_playbackFrame != f) {
@@ -219,7 +219,7 @@ sv_frame_t
 ViewManager::alignPlaybackFrameToReference(sv_frame_t frame) const
 {
 #ifdef DEBUG_VIEW_MANAGER
-    cerr << "ViewManager::alignPlaybackFrameToReference(" << frame << "): playback model is " << m_playbackModel << endl;
+    SVCERR << "ViewManager::alignPlaybackFrameToReference(" << frame << "): playback model is " << m_playbackModel << endl;
 #endif
     if (m_playbackModel.isNone() || !m_alignMode) {
         return frame;
@@ -230,7 +230,7 @@ ViewManager::alignPlaybackFrameToReference(sv_frame_t frame) const
         } 
         sv_frame_t f = playbackModel->alignToReference(frame);
 #ifdef DEBUG_VIEW_MANAGER
-        cerr << "aligned frame = " << f << endl;
+        SVCERR << "aligned frame = " << f << endl;
 #endif
         return f;
     }
@@ -240,7 +240,7 @@ sv_frame_t
 ViewManager::alignReferenceToPlaybackFrame(sv_frame_t frame) const
 {
 #ifdef DEBUG_VIEW_MANAGER
-    cerr << "ViewManager::alignReferenceToPlaybackFrame(" << frame << "): playback model is " << m_playbackModel << endl;
+    SVCERR << "ViewManager::alignReferenceToPlaybackFrame(" << frame << "): playback model is " << m_playbackModel << endl;
 #endif
     if (m_playbackModel.isNone() || !m_alignMode) {
         return frame;
@@ -251,7 +251,7 @@ ViewManager::alignReferenceToPlaybackFrame(sv_frame_t frame) const
         } 
         sv_frame_t f = playbackModel->alignFromReference(frame);
 #ifdef DEBUG_VIEW_MANAGER
-        cerr << "aligned frame = " << f << endl;
+        SVCERR << "aligned frame = " << f << endl;
 #endif
         return f;
     }
@@ -286,13 +286,13 @@ ViewManager::clearInProgressSelection()
     emit inProgressSelectionChanged();
 }
 
-const MultiSelection &
+MultiSelection
 ViewManager::getSelection() const
 {
     return m_selections;
 }
 
-const MultiSelection::SelectionList &
+MultiSelection::SelectionList
 ViewManager::getSelections() const
 {
     return m_selections.getSelections();
@@ -554,7 +554,7 @@ void
 ViewManager::playStatusChanged(bool /* playing */)
 {
 #ifdef DEBUG_VIEW_MANAGER
-    cerr << "ViewManager::playStatusChanged" << endl;
+    SVCERR << "ViewManager::playStatusChanged" << endl;
 #endif
     checkPlayStatus();
 }
@@ -563,7 +563,7 @@ void
 ViewManager::recordStatusChanged(bool /* recording */)
 {
 #ifdef DEBUG_VIEW_MANAGER
-    cerr << "ViewManager::recordStatusChanged" << endl;
+    SVCERR << "ViewManager::recordStatusChanged" << endl;
 #endif
     checkPlayStatus();
 }
@@ -585,7 +585,7 @@ ViewManager::checkPlayStatus()
         m_playbackFrame = m_recordTarget->getRecordDuration();
 
 #ifdef DEBUG_VIEW_MANAGER
-        cerr << "ViewManager::checkPlayStatus: Recording, frame " << m_playbackFrame << ", levels " << m_lastLeft << "," << m_lastRight << endl;
+        SVCERR << "ViewManager::checkPlayStatus: Recording, frame " << m_playbackFrame << ", levels " << m_lastLeft << "," << m_lastRight << endl;
 #endif
 
         emit playbackFrameChanged(m_playbackFrame);
@@ -606,7 +606,7 @@ ViewManager::checkPlayStatus()
         m_playbackFrame = m_playSource->getCurrentPlayingFrame();
 
 #ifdef DEBUG_VIEW_MANAGER
-        cerr << "ViewManager::checkPlayStatus: Playing, frame " << m_playbackFrame << ", levels " << m_lastLeft << "," << m_lastRight << endl;
+        SVCERR << "ViewManager::checkPlayStatus: Playing, frame " << m_playbackFrame << ", levels " << m_lastLeft << "," << m_lastRight << endl;
 #endif
 
         emit playbackFrameChanged(m_playbackFrame);
@@ -622,7 +622,7 @@ ViewManager::checkPlayStatus()
         }
 
 #ifdef DEBUG_VIEW_MANAGER
-        cerr << "ViewManager::checkPlayStatus: Not playing or recording" << endl;
+        SVCERR << "ViewManager::checkPlayStatus: Not playing or recording" << endl;
 #endif
     }
 }
@@ -646,7 +646,7 @@ ViewManager::viewCentreFrameChanged(sv_frame_t f, bool locked,
     View *v = dynamic_cast<View *>(sender());
 
 #ifdef DEBUG_VIEW_MANAGER
-    cerr << "ViewManager::viewCentreFrameChanged(" << f << ", " << locked << ", " << mode << "), view is " << v << endl;
+    SVCERR << "ViewManager::viewCentreFrameChanged(" << f << ", " << locked << ", " << mode << "), view is " << v << endl;
 #endif
 
     if (locked) {
@@ -674,13 +674,13 @@ void
 ViewManager::seek(sv_frame_t f)
 {
 #ifdef DEBUG_VIEW_MANAGER 
-    cerr << "ViewManager::seek(" << f << ")" << endl;
+    SVCERR << "ViewManager::seek(" << f << ")" << endl;
 #endif
 
     if (isRecording()) {
         // ignore
 #ifdef DEBUG_VIEW_MANAGER
-        cerr << "ViewManager::seek: Ignoring during recording" << endl;
+        SVCERR << "ViewManager::seek: Ignoring during recording" << endl;
 #endif
         return;
     }
@@ -692,7 +692,7 @@ ViewManager::seek(sv_frame_t f)
             m_playbackFrame = f;
             m_playSource->play(f);
 #ifdef DEBUG_VIEW_MANAGER 
-            cerr << "ViewManager::seek: reseeking from " << playFrame << " to " << f << endl;
+            SVCERR << "ViewManager::seek: reseeking from " << playFrame << " to " << f << endl;
 #endif
             emit playbackFrameChanged(f);
         }
@@ -721,7 +721,7 @@ ViewManager::viewZoomLevelChanged(ZoomLevel z, bool locked)
     }
 
 #ifdef DEBUG_VIEW_MANAGER 
-    cerr << "ViewManager::viewZoomLevelChanged(" << v << ", " << z << ", " << locked << ")" << endl;
+    SVCERR << "ViewManager::viewZoomLevelChanged(" << v << ", " << z << ", " << locked << ")" << endl;
 #endif
 
     emit viewZoomLevelChanged(v, z, locked);
@@ -798,8 +798,18 @@ ViewManager::setGlobalDarkBackground(bool dark)
     // since construction
     if (getGlobalDarkBackground()) {
         m_darkPalette = QApplication::palette();
+#ifdef DEBUG_VIEW_MANAGER
+        SVDEBUG << "ViewManager::setGlobalDarkBackground(" << dark << "): "
+                << "copied dark palette from existing widgets (window colour = "
+                << m_darkPalette.color(QPalette::Window).name() << ")" << endl;
+#endif
     } else {
         m_lightPalette = QApplication::palette();
+#ifdef DEBUG_VIEW_MANAGER
+        SVDEBUG << "ViewManager::setGlobalDarkBackground(" << dark << "): "
+                << "copied light palette from existing widgets (window colour = "
+                << m_lightPalette.color(QPalette::Window).name() << ")" << endl;
+#endif
     }
 
 #ifdef Q_OS_MAC
@@ -824,6 +834,12 @@ ViewManager::setGlobalDarkBackground(bool dark)
 #endif
 
         QApplication::setPalette(m_darkPalette);
+
+#ifdef DEBUG_VIEW_MANAGER
+        SVDEBUG << "ViewManager::setGlobalDarkBackground(" << dark << "): "
+                << "set dark palette to widgets (window colour = "
+                << m_darkPalette.color(QPalette::Window).name() << ")" << endl;
+#endif
         
     } else {
 
@@ -839,6 +855,12 @@ ViewManager::setGlobalDarkBackground(bool dark)
 #endif
         
         QApplication::setPalette(m_lightPalette);
+
+#ifdef DEBUG_VIEW_MANAGER
+        SVDEBUG << "ViewManager::setGlobalDarkBackground(" << dark << "): "
+                << "set light palette to widgets (window colour = "
+                << m_lightPalette.color(QPalette::Window).name() << ")" << endl;
+#endif
     }
 }
 
@@ -847,7 +869,13 @@ ViewManager::getGlobalDarkBackground() const
 {
     bool dark = false;
     QColor windowBg = QApplication::palette().color(QPalette::Window);
-    if (windowBg.red() + windowBg.green() + windowBg.blue() < 384) {
+    auto red = windowBg.red(), green = windowBg.green(), blue = windowBg.blue();
+#ifdef DEBUG_VIEW_MANAGER
+//    SVDEBUG << "ViewManager::getGlobalDarkBackground: red = " << red
+//            << ", green = " << green << ", blue = " << blue << ", total = "
+//            << red + green + blue << endl;
+#endif
+    if (red + green + blue < 384) {
         dark = true;
     }
     return dark;
@@ -877,3 +905,5 @@ ViewManager::scalePixelSize(int pixels)
     return scaled;
 }
 
+} // end namespace sv
+
