@@ -22,6 +22,8 @@
 class QListView;
 class QStringListModel;
 
+namespace sv {
+
 class ActivityLog : public QDialog
 {
     Q_OBJECT
@@ -40,4 +42,6 @@ private:
     QString m_prevName;
 };
 
+} // end namespace sv
+
 #endif
