@@ -26,6 +26,8 @@ class QCheckBox;
     
 #include <QDialog>
 
+namespace sv {
+
 class CSVFormatDialog : public QDialog
 {
     Q_OBJECT
@@ -98,4 +100,6 @@ protected:
     int m_fuzzyColumn;
 };
 
+} // end namespace sv
+
 #endif
