@@ -17,6 +17,8 @@
 
 #include <QLabel>
 
+namespace sv {
+
 class ClickableLabel : public QLabel
 {
     Q_OBJECT
@@ -36,4 +38,6 @@ protected:
     }
 };
 
+} // end namespace sv
+
 #endif
