@@ -18,6 +18,8 @@
 
 #include "NotifyingComboBox.h"
 
+namespace sv {
+
 /**
  * Colour map picker combo box with optional swatches
  */
@@ -39,5 +41,7 @@ private:
     bool m_includeSwatches;
 };
 
+} // end namespace sv
+
 #endif
 
