@@ -18,6 +18,8 @@
 
 #include <QIcon>
 
+namespace sv {
+
 class IconLoader
 {
 public:
@@ -36,6 +38,8 @@ private:
     QString makeNonScalableFilename(QString, int, bool);
 };
 
+} // end namespace sv
+
 #endif
 
         
