@@ -18,11 +18,14 @@
 
 #include <QDialog>
 
+class QTreeView;
+class QTableView;
+
+namespace sv {
+
 class ModelMetadataModel;
 class LayerTreeModel;
 class PaneStack;
-class QTreeView;
-class QTableView;
 
 class LayerTreeDialog : public QDialog
 {
@@ -40,4 +43,6 @@ protected:
     QTreeView *m_layerView;
 };
 
+} // end namespace sv
+
 #endif
