@@ -19,6 +19,8 @@
 
 #include "data/fileio/MIDIFileReader.h"
 
+namespace sv {
+
 class MIDIFileImportDialog : public QObject,
                              public MIDIFileImportPreferenceAcquirer
 {
@@ -37,4 +39,6 @@ protected:
     QWidget *m_parent;
 };
 
+} // end namespace sv
+
 #endif
