@@ -18,6 +18,8 @@
 
 #include <QTabBar>
 
+namespace sv {
+
 class NotifyingTabBar : public QTabBar
 {
     Q_OBJECT
@@ -33,8 +35,10 @@ signals:
 
 protected:
     void mousePressEvent(QMouseEvent *) override;
-    void enterEvent(QEvent *) override;
+    void enterEvent(QEnterEvent *) override;
     void leaveEvent(QEvent *) override;
 };
 
+} // end namespace sv
+
 #endif
