@@ -15,12 +15,14 @@
 
 #include "NotifyingToolButton.h"
 
+namespace sv {
+
 NotifyingToolButton::~NotifyingToolButton()
 {
 }
 
 void
-NotifyingToolButton::enterEvent(QEvent *e)
+NotifyingToolButton::enterEvent(QEnterEvent *e)
 {
     QToolButton::enterEvent(e);
     emit mouseEntered();
@@ -29,7 +31,9 @@ NotifyingToolButton::enterEvent(QEvent *e)
 void
 NotifyingToolButton::leaveEvent(QEvent *e)
 {
-    QToolButton::enterEvent(e);
+    QToolButton::leaveEvent(e);
     emit mouseLeft();
 }
 
+} // end namespace sv
+
