@@ -43,6 +43,8 @@
 
 #include "base/Debug.h"
 
+namespace sv {
+
 PluginParameterDialog::PluginParameterDialog(std::shared_ptr<Vamp::PluginBase> plugin,
                                              QWidget *parent) :
     QDialog(parent),
@@ -67,7 +69,7 @@ PluginParameterDialog::PluginParameterDialog(std::shared_ptr<Vamp::PluginBase> p
     pluginBox->setLayout(subgrid);
 
     subgrid->setSpacing(0);
-    subgrid->setMargin(10);
+    subgrid->setContentsMargins(10, 10, 10, 10);
 
     QFont boldFont(pluginBox->font());
     boldFont.setBold(true);
@@ -183,7 +185,7 @@ PluginParameterDialog::PluginParameterDialog(std::shared_ptr<Vamp::PluginBase> p
     grid->setRowStretch(2, 10);
 
     QHBoxLayout *paramLayout = new QHBoxLayout;
-    paramLayout->setMargin(0);
+    paramLayout->setContentsMargins(0, 0, 0, 0);
     paramBox->setLayout(paramLayout);
 
     QScrollArea *scroll = new QScrollArea;
@@ -199,7 +201,7 @@ PluginParameterDialog::PluginParameterDialog(std::shared_ptr<Vamp::PluginBase> p
 
     m_advanced = new QFrame;
     QVBoxLayout *advancedLayout = new QVBoxLayout;
-    advancedLayout->setMargin(0);
+    advancedLayout->setContentsMargins(0, 0, 0, 0);
     m_advanced->setLayout(advancedLayout);
     grid->addWidget(m_advanced, 3, 0);
 
@@ -317,7 +319,7 @@ PluginParameterDialog::setChannelArrangement(int sourceChannels,
         } else {
 
             if (m_haveChannelBoxData) {
-                cerr << "WARNING: PluginParameterDialog::setChannelArrangement: Calling more than once on same dialog is not currently implemented" << endl;
+                SVCERR << "WARNING: PluginParameterDialog::setChannelArrangement: Calling more than once on same dialog is not currently implemented" << endl;
                 return;
             }
             
@@ -362,7 +364,7 @@ PluginParameterDialog::setShowProcessingOptions(bool showWindowSize,
                                                 bool showFrequencyDomainOptions)
 {
     if (m_haveWindowBoxData) {
-        cerr << "WARNING: PluginParameterDialog::setShowProcessingOptions: Calling more than once on same dialog is not currently implemented" << endl;
+        SVCERR << "WARNING: PluginParameterDialog::setShowProcessingOptions: Calling more than once on same dialog is not currently implemented" << endl;
         return;
     }
 
@@ -373,7 +375,7 @@ PluginParameterDialog::setShowProcessingOptions(bool showWindowSize,
         int increment = 1024;
         if (fePlugin) {
             size = int(fePlugin->getPreferredBlockSize());
-            cerr << "Feature extraction plugin \"" << fePlugin->getName() << "\" reports preferred block size as " << size << endl;
+            SVCERR << "Feature extraction plugin \"" << fePlugin->getName() << "\" reports preferred block size as " << size << endl;
             if (size == 0) size = 1024;
             increment = int(fePlugin->getPreferredStepSize());
             if (increment == 0) {
@@ -394,7 +396,7 @@ PluginParameterDialog::setShowProcessingOptions(bool showWindowSize,
             windowLayout->addWidget(new QLabel(tr("Audio frames per block:")), 0, 0);
         }
 
-        cerr << "size: " << size << ", increment: " << increment << endl;
+        SVCERR << "size: " << size << ", increment: " << increment << endl;
 
         QComboBox *blockSizeCombo = new QComboBox;
         blockSizeCombo->setEditable(true);
@@ -547,7 +549,7 @@ void
 PluginParameterDialog::blockSizeComboChanged(const QString &text)
 {
     m_blockSize = text.toInt();
-    cerr << "Block size changed to " << m_blockSize << endl;
+    SVCERR << "Block size changed to " << m_blockSize << endl;
 }
 
 void
@@ -555,7 +557,7 @@ PluginParameterDialog::incrementComboChanged(const QString &text)
 {
     m_stepSize = text.toInt();
     //!!! rename increment to step size throughout
-    cerr << "Increment changed to " << m_stepSize << endl;
+    SVCERR << "Increment changed to " << m_stepSize << endl;
 }
 
 void
@@ -644,3 +646,5 @@ PluginParameterDialog::dialogAccepted()
     accept();
 }
 
+} // end namespace sv
+
