@@ -24,7 +24,6 @@
 
 #include <memory>
 
-class PluginParameterBox;
 class QWidget;
 class QPushButton;
 class QLabel;
@@ -32,6 +31,10 @@ class QGroupBox;
 class QComboBox;
 class QCheckBox;
 
+namespace sv {
+
+class PluginParameterBox;
+
 /**
  * A dialog for editing the parameters of a given plugin, using a
  * PluginParameterBox.  This dialog does not contain any mechanism for
@@ -131,5 +134,7 @@ protected:
     bool m_advancedVisible;
 };
 
+} // end namespace sv
+
 #endif
 
