@@ -20,6 +20,8 @@
 #include <QTabWidget>
 #include <vector>
 
+namespace sv {
+
 class Layer;
 class View;
 class PropertyBox;
@@ -70,4 +72,6 @@ protected:
     void updateValues(PropertyContainer *);
 };
 
+} // end namespace sv
+
 #endif
