@@ -18,6 +18,8 @@
 
 #include <QLabel>
 
+namespace sv {
+
 class SelectableLabel : public QLabel
 {
     Q_OBJECT
@@ -43,7 +45,7 @@ protected:
     void mousePressEvent(QMouseEvent *e) override;
     void mouseReleaseEvent(QMouseEvent *e) override;
     void mouseDoubleClickEvent(QMouseEvent *e) override;
-    void enterEvent(QEvent *) override;
+    void enterEvent(QEnterEvent *) override;
     void leaveEvent(QEvent *) override;
     void setupStyle();
     QString m_selectedText;
@@ -52,4 +54,6 @@ protected:
     bool m_swallowRelease;
 };
 
+} // end namespace sv
+
 #endif
