@@ -22,6 +22,8 @@
 
 class QFontMetrics;
 
+namespace sv {
+
 class TextAbbrev 
 {
 public:
@@ -105,5 +107,7 @@ protected:
     static std::set<QString> getCommonPrefixes(const QStringList &texts);
 };
 
+} // end namespace sv
+
 #endif
 
